#include <nexus-rest-api.h>

/**
 * Enunciate-specific C functions.
 */
#ifndef ENUNCIATE_C_UTILITIES
#define ENUNCIATE_C_UTILITIES

/*******************xml utilities************************************/

static int xmlTextReaderAdvanceToNextStartOrEndElement(xmlTextReaderPtr reader) {
  int status = xmlTextReaderRead(reader);
  while (status && xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT && xmlTextReaderNodeType(reader) != XML_READER_TYPE_END_ELEMENT) {
    status = xmlTextReaderRead(reader);
  }
  return status;
}

static int xmlTextReaderSkipElement(xmlTextReaderPtr reader) {
  int status = xmlTextReaderNext(reader);
  while (status && xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT && xmlTextReaderNodeType(reader) != XML_READER_TYPE_END_ELEMENT) {
    status = xmlTextReaderRead(reader);
  }
  return status;
}

static xmlChar *xmlTextReaderReadEntireNodeValue(xmlTextReaderPtr reader) {
  xmlChar *buffer = calloc(1, sizeof(xmlChar));
  const xmlChar *snippet;
  int status;
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ATTRIBUTE) {
    return xmlTextReaderValue(reader);
  }
  else if (xmlTextReaderIsEmptyElement(reader) == 0) {
    status = xmlTextReaderRead(reader);
    while (status && (xmlTextReaderNodeType(reader) == XML_READER_TYPE_TEXT || xmlTextReaderNodeType(reader) == XML_READER_TYPE_CDATA || xmlTextReaderNodeType(reader) == XML_READER_TYPE_ENTITY_REFERENCE)) {
      snippet = xmlTextReaderConstValue(reader);
      buffer = realloc(buffer, (xmlStrlen(buffer) + xmlStrlen(snippet) + 1) * sizeof(xmlChar));
      xmlStrcat(buffer, snippet);
      status = xmlTextReaderRead(reader);
    }
  }
  return buffer;
}

/*******************base 64 utilities************************************/

/*
 * Base64 Translation Table as described in RFC1113.
 *
 * This code was graciously ripped from http://base64.sourceforge.net
 */
static const char cb64[]="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";

/*
 * Base64 Translation Table to decode (created by author)
 *
 * This code was graciously ripped from http://base64.sourceforge.net
 */
static const char cd64[]="|$$$}rstuvwxyz{$$$$$$$>?@ABCDEFGHIJKLMNOPQRSTUVW$$$$$$XYZ[\\]^_`abcdefghijklmnopq";

/*
 * encode 3 8-bit binary bytes as 4 '6-bit' characters
 *
 * This code was graciously ripped from http://base64.sourceforge.net
 *
 * @param in the block to encode
 * @param out the block to encode to
 * @param len the length of the 'in' block.
 */
static void _encode_base64_block(unsigned char in[3], unsigned char out[4], int len) {
  out[0] = cb64[ in[0] >> 2 ];
  out[1] = cb64[ ((in[0] & 0x03) << 4) | ((in[1] & 0xf0) >> 4) ];
  out[2] = (unsigned char) (len > 1 ? cb64[ ((in[1] & 0x0f) << 2) | ((in[2] & 0xc0) >> 6) ] : '=');
  out[3] = (unsigned char) (len > 2 ? cb64[ in[2] & 0x3f ] : '=');
}

/*
 * decode 4 '6-bit' characters into 3 8-bit binary bytes
 *
 * This code was graciously ripped from http://base64.sourceforge.net
 */
static void _decode_base64_block( unsigned char in[4], unsigned char out[3] )
{
    out[ 0 ] = (unsigned char ) (in[0] << 2 | in[1] >> 4);
    out[ 1 ] = (unsigned char ) (in[1] << 4 | in[2] >> 2);
    out[ 2 ] = (unsigned char ) (((in[2] << 6) & 0xc0) | in[3]);
}

/*
 * base64 encode a stream adding padding and line breaks as per spec.
 *
 * This code was graciously ripped from http://base64.sourceforge.net
 *
 * @param instream The stream to encode.
 * @param insize The size of the stream to encode.
 * @return The encoded string.
 */
xmlChar *_encode_base64(unsigned char *instream, int insize) {
  unsigned char in[3];
  unsigned char out[4];
  xmlChar *encoded;
  int i, in_index = 0, out_index = 0, blocklen;

  if (insize == 0) {
    return BAD_CAST "\0";
  }

  encoded = calloc(((insize / 3) * 4) + 10, sizeof(xmlChar));
  while (in_index <= insize) {
    blocklen = 0;
    for (i = 0; i < 3; i++) {
      in[i] = instream[in_index++];
      if (in_index <= insize) {
        blocklen++;
      }
      else {
        in[i] = 0;
      }
    }
    if (blocklen) {
      _encode_base64_block(in, out, blocklen);
      for( i = 0; i < 4; i++ ) {
        encoded[out_index++] = out[i];
      }
    }
  }

  return encoded;
}

/*
 * Decode a base64 encoded stream discarding padding, line breaks and noise
 *
 * This code was graciously ripped from http://base64.sourceforge.net
 *
 * @param invalue The string to decode.
 * @param outsize Holder for the length of the returned data.
 * @return The decoded data.
 */
unsigned char *_decode_base64( const xmlChar *invalue, int *outsize ) {
  xmlChar in[4];
  unsigned char out[3], v;
  int i, in_index = 0, out_index = 0, blocklen;
  unsigned char *outstream;

  if (invalue == NULL) {
    return NULL;
  }

  outstream = calloc(((xmlStrlen(invalue) / 4) * 3) + 1, sizeof(unsigned char));
  while (invalue[in_index] != '\0') {
    for (blocklen = 0, i = 0; i < 4 && invalue[in_index]; i++) {
      v = 0;
      while (invalue[in_index] != '\0' && v == 0) {
        v = (unsigned char) invalue[in_index++];
        v = (unsigned char) ((v < 43 || v > 122) ? 0 : cd64[ v - 43 ]);
        if (v) {
          v = (unsigned char) ((v == '$') ? 0 : v - 61);
        }
      }

      if (invalue[in_index] != '\0') {
        blocklen++;
        if (v) {
          in[i] = (unsigned char) (v - 1);
        }
      }
      else {
        in[i] = 0;
      }
    }

    if (blocklen) {
      _decode_base64_block( in, out );
      for( i = 0; i < blocklen - 1; i++ ) {
        outstream[out_index++] = out[i];
      }
    }
  }

  if (outsize != NULL) {
    *outsize = out_index;
  }

  return outstream;
}

#endif /* ENUNCIATE_C_UTILITIES */

#ifndef ENUNCIATE_OBJC_CLASSES
#define ENUNCIATE_OBJC_CLASSES

/**
 * Protocol defining a JAXB (see https://jaxb.dev.java.net/) type.
 */
@protocol JAXBType

/**
 * Read an XML type from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of the object defining the JAXB type.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader;

/**
 * Initialize the object with an XML reader.
 *
 * @param reader The XML reader from which to initialize the values of this type.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader;

/**
 * Write this instance of a JAXB type to a writer.
 *
 * @param writer The writer.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer;

@end /*protocol JAXBType*/


/**
 * Protocol defining a JAXB (see https://jaxb.dev.java.net/) element.
 */
@protocol JAXBElement

/**
 * Read the XML element from an XML reader. It is assumed
 * that the reader is pointing at the start element (be careful
 * that it's not still pointing to the XML document).
 *
 * @param reader The reader.
 * @return An instance of the object defining the JAXB element.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader;

/**
 * Write this instance of a JAXB element to a writer.
 *
 * @param writer The writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer;

/**
 * Write this instance of a JAXB element to a writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs;

@end /*protocol JAXBElement*/


/**
 * Protocol defining methods for events that occur
 * when reading/parsing XML. Intended for internal
 * use only.
 */
@protocol JAXBReading

/**
 * Method for reading an attribute.
 *
 * @param reader The reader pointing to the attribute.
 * @return Whether the attribute was read.
 */
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader;

/**
 * Method for reading the value of an element.
 *
 * @param reader The reader pointing to the element containing a value.
 * @return Whether the value was read.
 */
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader;

/**
 * Method for reading a child element. If (and only if) the child
 * element was handled, the element in the reader should be
 * "consumed" and the reader will be pointing to the end element.
 *
 * @param reader The reader pointing to the child element.
 * @return Whether the child element was read.
 */
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader;

/**
 * Method for reading an unknown attribute.
 *
 * @param reader The reader pointing to the unknown attribute.
 * @return Whether the attribute was read.
 */
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader;

/**
 * Method for reading an unknown child element. Implementations
 * must be responsible for "consuming" the child element.
 *
 * @param reader The reader pointing to the unknown child element.
 * @return The status of the reader after having consumed the unknown child element.
 */
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader;

@end /*protocol JAXBReading*/

/**
 * Protocol defining methods for events that occur
 * when writing XML. Intended for internal
 * use only.
 */
@protocol JAXBWriting

/**
 * Method for writing the attributes.
 *
 * @param writer The writer.
 */
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer;

/**
 * Method for writing the element value.
 *
 * @param writer The writer.
 */
- (void) writeJAXBValue: (xmlTextWriterPtr) writer;

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer;

@end /*protocol JAXBWriting*/

/**
 * Declaration of the JAXB type, element, events for a base object.
 */
@interface NSObject (JAXB) <JAXBType, JAXBElement, JAXBReading, JAXBWriting>

@end

/**
 * Implementation of the JAXB type, element, events for a base object.
 */
@implementation NSObject (JAXB)

/**
 * Read the XML type from the reader; an instance of NSXMLElement.
 *
 * @param reader The reader.
 * @return An instance of NSXMLElement
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  return [JAXBBasicXMLNode readXMLType: reader];
}

/**
 * Read an XML type from an XML reader into an existing instance.
 *
 * @param reader The reader.
 * @param existing The existing instance into which to read values.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  int status, depth;
  if ((self = [self init])) {
    if (xmlTextReaderHasAttributes(reader)) {
      while (xmlTextReaderMoveToNextAttribute(reader)) {
        if ([self readJAXBAttribute: reader] == NO) {
          [self readUnknownJAXBAttribute: reader];
        }
      }

      status = xmlTextReaderMoveToElement(reader);
      if (!status) {
        //panic: unable to return to the element node.
        [NSException raise: @"XMLReadError"
                     format: @"Error moving back to element position from attributes."];
      }
    }

    if ([self readJAXBValue: reader] == NO) {
      //no value handled; attempt to process child elements
      if (xmlTextReaderIsEmptyElement(reader) == 0) {
        depth = xmlTextReaderDepth(reader);//track the depth.
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
        while (xmlTextReaderDepth(reader) > depth) {
          if (status < 1) {
            //panic: XML read error.
            [NSException raise: @"XMLReadError"
                         format: @"Error handling a child element."];
          }
          else if ([self readJAXBChildElement: reader]) {
            status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
          }
          else {
            status = [self readUnknownJAXBChildElement: reader];
          }
        }
      }
    }
  }
  return self;
}

/**
 * Write the XML type value of this object to the writer.
 *
 * @param writer The writer.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [self writeJAXBAttributes: writer];
  [self writeJAXBValue: writer];
  [self writeJAXBChildElements: writer];
}

/**
 * Read the XML element from the reader; an instance of NSXMLElement.
 *
 * @param reader The reader.
 * @return An instance of NSXMLElement
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader
{
  return (id<JAXBElement>) [JAXBBasicXMLNode readXMLType: reader];
}

/**
 * No op; root objects don't have an element name/namespace. Subclasses must override.
 *
 * @param writer The writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  //no-op
}

/**
 * No op; root objects don't have an element name/namespace. Subclasses must override.
 *
 * @param writer The writer.
 * @param writeNs Ignored.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  //no-op
}

/**
 * No-op; base objects do not handle any attributes.
 *
 * @param reader The reader pointing to the attribute.
 * @return NO
 */
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  return NO;
}

/**
 * No-op; base objects do not handle any values.
 *
 * @param reader The reader pointing to the element containing a value.
 * @return NO
 */
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return NO;
}

/**
 * No-op; base objects do not handle any child elements.
 *
 * @param reader The reader pointing to the child element.
 * @return NO
 */
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  return NO;
}

/**
 * No-op; base objects do not handle any attributes.
 *
 * @param reader The reader pointing to the unknown attribute.
 */
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
}

/**
 * Just skips the unknown element; base objects do not handle any child elements.
 *
 * @param reader The reader pointing to the unknown child element.
 * @return The status of the reader after skipping the unknown child element.
 */
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return xmlTextReaderSkipElement(reader);
}

/**
 * No-op; base objects have no attributes.
 *
 * @param writer The writer.
 */
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  //no-op.
}

/**
 * No-op; base objects have no element value.
 *
 * @param writer The writer.
 */
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  //no-op.
}

/**
 * No-op; base objects have no child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  //no-op.
}

@end /*NSObject (JAXB)*/

/**
 * Implementation of the JAXB type, element for an xml element.
 */
@implementation JAXBBasicXMLNode

/**
 * Accessor for the (local) name of the XML node.
 *
 * @return The (local) name of the XML node.
 */
- (NSString *) name
{
  return _name;
}

/**
 * Accessor for the (local) name of the XML node.
 *
 * @param newName The (local) name of the XML node.
 */
- (void) setName: (NSString *) newName
{
  [newName retain];
  [_name release];
  _name = newName;
}

/**
 * Accessor for the namespace of the XML node.
 *
 * @return The namespace of the XML node.
 */
- (NSString *) ns
{
  return _ns;
}

/**
 * Accessor for the namespace of the XML node.
 *
 * @param newNs The namespace of the XML node.
 */
- (void) setNs: (NSString *) newNs
{
  [newNs retain];
  [_ns release];
  _ns = newNs;
}

/**
 * Accessor for the namespace prefix of the XML node.
 *
 * @return The namespace prefix of the XML node.
 */
- (NSString *) prefix
{
  return _prefix;
}

/**
 * Accessor for the namespace prefix of the XML node.
 *
 * @param newPrefix The namespace prefix of the XML node.
 */
- (void) setPrefix: (NSString *) newPrefix
{
  [newPrefix retain];
  [_prefix release];
  _prefix = newPrefix;
}

/**
 * Accessor for the value of the XML node.
 *
 * @return The value of the XML node.
 */
- (NSString *) value
{
  return _value;
}

/**
 * Accessor for the value of the XML node.
 *
 * @param newValue The value of the XML node.
 */
- (void) setValue: (NSString *) newValue
{
  [newValue retain];
  [_value release];
  _value = newValue;
}

/**
 * Accessor for the child elements of the XML node.
 *
 * @return The child elements of the XML node.
 */
- (NSArray *) childElements
{
  return _childElements;
}

/**
 * Accessor for the child elements of the XML node.
 *
 * @param newValue The child elements of the XML node.
 */
- (void) setChildElements: (NSArray *) newChildElements
{
  [newChildElements retain];
  [_childElements release];
  _childElements = newChildElements;
}

/**
 * Accessor for the attributes of the XML node.
 *
 * @return The attributes of the XML node.
 */
- (NSArray *) attributes
{
  return _attributes;
}

/**
 * Accessor for the attributes of the XML node.
 *
 * @param newAttributes The attributes of the XML node.
 */
- (void) setAttributes: (NSArray *) newAttributes
{
  [newAttributes retain];
  [_attributes release];
  _attributes = newAttributes;
}

- (void) dealloc {
  [self setName: nil];
  [self setNs: nil];
  [self setPrefix: nil];
  [self setValue: nil];
  [self setChildElements: nil];
  [self setAttributes: nil];
  [super dealloc];
}
@end /*implementation JAXBBasicXMLNode*/

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface JAXBBasicXMLNode (JAXB) <JAXBType, JAXBElement>

@end /*interface JAXBBasicXMLNode (JAXB)*/

@implementation JAXBBasicXMLNode (JAXB)

/**
 * Read the XML type from the reader; an instance of JAXBBasicXMLNode.
 *
 * @param reader The reader.
 * @return An instance of JAXBBasicXMLNode
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  JAXBBasicXMLNode *node = [[JAXBBasicXMLNode alloc] init];
  NS_DURING
  {
    [node initWithReader: reader];
  }
  NS_HANDLER
  {
    [node dealloc];
    node = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [node autorelease];
  return node;
}

/**
 * Read an XML type from an XML reader into an existing instance of JAXBBasicXMLNode.
 *
 * @param reader The reader.
 * @param existing The existing instance into which to read values.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  int status, depth;
  JAXBBasicXMLNode *child;
  xmlChar *value = NULL;
  const xmlChar *text;
  NSMutableArray *children;

  if ((self = [self init])) {
    depth = xmlTextReaderDepth(reader);
    [self setName: [NSString stringWithUTF8String: (const char *) xmlTextReaderLocalName(reader)]];
    [self setNs: [NSString stringWithUTF8String: (const char *) xmlTextReaderNamespaceUri(reader)]];
    [self setPrefix: [NSString stringWithUTF8String: (const char *)xmlTextReaderPrefix(reader)]];

    if (xmlTextReaderHasAttributes(reader)) {
      child = nil;
      children = [[NSMutableArray alloc] init];
      while (xmlTextReaderMoveToNextAttribute(reader)) {
        child = [[JAXBBasicXMLNode alloc] init];
        [child setName: [NSString stringWithUTF8String: (const char *) xmlTextReaderLocalName(reader)]];
        [child setNs: [NSString stringWithUTF8String: (const char *)xmlTextReaderNamespaceUri(reader)]];
        [child setPrefix: [NSString stringWithUTF8String: (const char *) xmlTextReaderPrefix(reader)]];
        [child setValue: [NSString stringWithUTF8String: (const char *) xmlTextReaderValue(reader)]];
        [children addObject: child];
      }
      [self setAttributes: children];

      status = xmlTextReaderMoveToElement(reader);
      if (status < 1) {
        //panic: unable to return to the element node.
        [NSException raise: @"XMLReadError"
                     format: @"Error moving to element from attributes."];
      }
    }

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
      children = [[NSMutableArray alloc] init];
      status = xmlTextReaderRead(reader);
      while (status == 1 && xmlTextReaderDepth(reader) > depth) {
        switch (xmlTextReaderNodeType(reader)) {
          case XML_READER_TYPE_ELEMENT:
            child = (JAXBBasicXMLNode *) [JAXBBasicXMLNode readXMLType: reader];
            [children addObject: child];
            break;
          case XML_READER_TYPE_TEXT:
          case XML_READER_TYPE_CDATA:
            text = xmlTextReaderConstValue(reader);
            value = xmlStrncat(value, text, xmlStrlen(text));
            break;
          default:
            //skip anything else.
            break;
        }

        status = xmlTextReaderRead(reader);
      }

      if (status < 1) {
        //panic: xml read error
        [NSException raise: @"XMLReadError"
                     format: @"Error reading child elements."];
      }

      if ([children count] > 0) {
        [self setChildElements: children];
      }

      if (value != NULL) {
        [self setValue: [NSString stringWithUTF8String: (const char *) value]];
      }

    }
  }

  return self;
}

/**
 * Read the XML element from the reader; an instance of NSXMLElement.
 *
 * @param reader The reader.
 * @return An instance of NSXMLElement
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader
{
  return (id<JAXBElement>) [JAXBBasicXMLNode readXMLType: reader];
}

/**
 * Write the basic node to an xml writer.
 *
 * @param writer The writer.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  int status;
  NSEnumerator *enumerator;
  JAXBBasicXMLNode *child;
  xmlChar *childns, *childname, *childprefix, *childvalue;

  status = xmlTextWriterStartElementNS(writer, _prefix ? BAD_CAST [_prefix UTF8String] : NULL, _name ? BAD_CAST [_name UTF8String] : NULL, _ns ? BAD_CAST [_ns UTF8String] : NULL);
  if (status < 0) {
    childns = BAD_CAST "";
    if (_ns) {
      childns = BAD_CAST [_ns UTF8String];
    }

    childname = BAD_CAST "";
    if (_name) {
      childname = BAD_CAST [_name UTF8String];
    }

    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {%s}%s for JAXBBasicXMLNode.", childns, childname];
  }

  if (_attributes) {
    enumerator = [_attributes objectEnumerator];
    while ( (child = (JAXBBasicXMLNode *)[enumerator nextObject]) ) {
      childns = NULL;
      if ([child ns]) {
        childns = BAD_CAST [[child ns] UTF8String];
      }

      childprefix = NULL;
      if ([child prefix]) {
        childprefix = BAD_CAST [[child prefix] UTF8String];
      }

      childname = NULL;
      if ([child name]) {
        childname = BAD_CAST [[child name] UTF8String];
      }

      childvalue = NULL;
      if ([child value]) {
        childvalue = BAD_CAST [[child value] UTF8String];
      }

      status = xmlTextWriterWriteAttributeNS(writer, childprefix, childname, childns, childvalue);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing attribute {%s}%s for JAXBBasicXMLNode.", childns, childname];
      }
    }
  }

  if (_value) {
    status = xmlTextWriterWriteString(writer, BAD_CAST [_value UTF8String]);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing value of JAXBBasicXMLNode."];
    }
  }

  if (_childElements) {
    enumerator = [_childElements objectEnumerator];
    while ( (child = [enumerator nextObject]) ) {
      [child writeXMLType: writer];
    }
  }

  status = xmlTextWriterEndElement(writer);
  if (status < 0) {
    childns = BAD_CAST "";
    if (_ns) {
      childns = BAD_CAST [_ns UTF8String];
    }

    childname = BAD_CAST "";
    if (_name) {
      childname = BAD_CAST [_name UTF8String];
    }

    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {%s}%s for JAXBBasicXMLNode.", childns, childname];
  }
}

/**
 * Writes this node to a writer.
 *
 * @param writer The writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLType: writer];
}

/**
 * Writes this node to a writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  [self writeXMLType: writer];
}

@end /* implementation JAXBBasicXMLNode (JAXB) */

/**
 * Declaration of the JAXB type for a string.
 */
@interface NSString (JAXBType) <JAXBType>
@end

/**
 * Implementation of the JAXB type for a string.
 */
@implementation NSString (JAXBType)

/**
 * Read the XML type from the reader.
 *
 * @param reader The reader.
 * @return The NSString that was read from the reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  return [NSString stringWithUTF8String: (const char *) xmlTextReaderReadEntireNodeValue(reader)];
}

/**
 * Read an XML type from an XML reader into an existing instance.
 *
 * @param reader The reader.
 * @param existing The existing instance into which to read values.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  [NSException raise: @"XMLReadError"
               format: @"An existing string cannot be modified."];
  return nil;
}

/**
 * Write the NSString to the writer.
 *
 * @param writer The writer.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  xmlTextWriterWriteString(writer, BAD_CAST [self UTF8String]);
}

@end /*NSString (JAXBType)*/



/**
 * Declaration of the JAXB type for a big number.
 */
@interface NSNumber (JAXBType) <JAXBType>
@end

/**
 * Implementation of the JAXB type for a big number.
 */
@implementation NSNumber (JAXBType)

/**
 * Read the XML type from the reader.
 *
 * @param reader The reader.
 * @return The NSNumber that was read from the reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  return [NSNumber numberWithLongLong: [[NSString stringWithUTF8String: (const char *) xmlTextReaderReadEntireNodeValue(reader)] longLongValue]];
}

/**
 * Read an XML type from an XML reader into an existing instance.
 *
 * @param reader The reader.
 * @param existing The existing instance into which to read values.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  [NSException raise: @"XMLReadError"
               format: @"An existing number cannot be modified."];
  return nil;
}

/**
 * Write the NSNumber to the writer.
 *
 * @param writer The writer.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  xmlTextWriterWriteString(writer, BAD_CAST [[self description] UTF8String]);
}

@end /*NSNumber (JAXBType)*/



/**
 * Declaration of the JAXB type for a big number.
 */
@interface NSDecimalNumber (JAXBType) <JAXBType>
@end

/**
 * Implementation of the JAXB type for a big number.
 */
@implementation NSDecimalNumber (JAXBType)

/**
 * Read the XML type from the reader.
 *
 * @param reader The reader.
 * @return The NSDecimalNumber that was read from the reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  return [NSDecimalNumber decimalNumberWithString: [NSString stringWithUTF8String: (const char *) xmlTextReaderReadEntireNodeValue(reader)]];
}

/**
 * Read an XML type from an XML reader into an existing instance.
 *
 * @param reader The reader.
 * @param existing The existing instance into which to read values.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  [NSException raise: @"XMLReadError"
               format: @"An existing decimal number cannot be modified."];
  return nil;
}

/**
 * Write the NSDecimalNumber to the writer.
 *
 * @param writer The writer.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  xmlTextWriterWriteString(writer, BAD_CAST [[self description] UTF8String]);
}

@end /*NSDecimalNumber (JAXBType)*/



/**
 * Declaration of the JAXB type for a url.
 */
@interface NSURL (JAXBType) <JAXBType>
@end

/**
 * Implementation of the JAXB type for a url.
 */
@implementation NSURL (JAXBType)

/**
 * Read the XML type from the reader.
 *
 * @param reader The reader.
 * @return The NSURL that was read from the reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  return [NSURL URLWithString: [NSString stringWithUTF8String: (const char *) xmlTextReaderReadEntireNodeValue(reader)]];
}

/**
 * Read an XML type from an XML reader into an existing instance.
 *
 * @param reader The reader.
 * @param existing The existing instance into which to read values.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  [NSException raise: @"XMLReadError"
               format: @"An existing url cannot be modified."];
  return nil;
}

/**
 * Write the NSURL to the writer.
 *
 * @param writer The writer.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  xmlTextWriterWriteString(writer, BAD_CAST [[self absoluteString] UTF8String]);
}

@end /*NSURL (JAXBType)*/



/**
 * Declaration of the JAXB type for binary data.
 */
@interface NSData (JAXBType) <JAXBType>
@end

/**
 * Implementation of the JAXB type for a binary data.
 */
@implementation NSData (JAXBType)

/**
 * Read the XML type from the reader.
 *
 * @param reader The reader.
 * @return The NSData that was read from the reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  xmlChar *base64data = xmlTextReaderReadEntireNodeValue(reader);
  int len;
  unsigned char *data = _decode_base64(base64data, &len);
  NSData *wrappedData = [NSData dataWithBytesNoCopy: data length: len];
  free(base64data);
  return wrappedData;
}

/**
 * Read an XML type from an XML reader into an existing instance.
 *
 * @param reader The reader.
 * @param existing The existing instance into which to read values.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  [NSException raise: @"XMLReadError"
               format: @"An existing NSData cannot be modified."];
  return nil;
}

/**
 * Write the NSData to the writer.
 *
 * @param writer The writer.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  xmlChar *out = _encode_base64((unsigned char *)[self bytes], [self length]);
  xmlTextWriterWriteString(writer, out);
  free(out);
}

@end /*NSData (JAXBType)*/



/**
 * Declaration of the JAXB type for a big number.
 */
@interface NSDate (JAXBType) <JAXBType>
@end

/**
 * Implementation of the JAXB type for a big number.
 */
@implementation NSDate (JAXBType)

/**
 * Read the XML type from the reader.
 *
 * @param reader The reader.
 * @return The NSDate that was read from the reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  xmlChar *timevalue = xmlTextReaderReadEntireNodeValue(reader);
  NSInteger year = 0;
  NSUInteger month = 1, day = 1, hour = 0, minute = 0, second = 0;
  BOOL skip_time = NO;
  int index = 0, token_index = 0, len = xmlStrlen(timevalue), offset_hour = 0, offset_minute = 0;
  char token[len];

  if (len > (index + 5) && timevalue[index + 4] == '-') {
    //assume we're at yyyy-MM-dd
    token_index = 0;
    while (index < len && timevalue[index] != '-') {
      token[token_index++] = timevalue[index++];
    }
    token[token_index] = '\0';
    if (token_index != 4) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read dateTime %s; invalid year: %s", timevalue, token];
    }
    year = atoi(token);
    index++;

    //go to next '-' character.
    token_index = 0;
    while (index < len && timevalue[index] != '-') {
      token[token_index++] = timevalue[index++];
    }
    token[token_index] = '\0';
    if (token_index != 2) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read dateTime %s; invalid month: %s", timevalue, token];
    }
    month = atoi(token);
    index++;

    //go to 'T', 'Z', '+', or '-' character.
    token_index = 0;
    while (index < len && timevalue[index] != 'T' && timevalue[index] != 'Z' && timevalue[index] != '-' && timevalue[index] != '+') {
      token[token_index++] = timevalue[index++];
    }
    token[token_index] = '\0';
    if (token_index != 2) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read dateTime %s; invalid day of month: %s", timevalue, token];
    }
    day = atoi(token);
    if (timevalue[index] != 'T') {
      skip_time = YES;
    }
    if (timevalue[index] != '-') {
      index++;
    }
  }

  if (skip_time == NO || (len > (index + 3) && timevalue[index + 2] == ':')) {
    //assume we're at HH:mm:ss

    //go to ':' character.
    token_index = 0;
    while (index < len && timevalue[index] != ':') {
      token[token_index++] = timevalue[index++];
    }
    token[token_index] = '\0';
    if (token_index != 2) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read dateTime %s; invalid hour: %s", timevalue, token];
    }
    hour = atoi(token);
    index++;

    //go to ':' character.
    token_index = 0;
    while (index < len && timevalue[index] != ':') {
      token[token_index++] = timevalue[index++];
    }
    token[token_index] = '\0';
    if (token_index != 2) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read dateTime %s; invalid minute: %s", timevalue, token];
    }
    minute = atoi(token);
    index++;

    //go to '+' or '-' or 'Z' character.
    token_index = 0;
    while (index < len && timevalue[index] != '+' && timevalue[index] != '-' && timevalue[index] != 'Z') {
      token[token_index++] = timevalue[index++];
    }
    token[token_index] = '\0';
    if (token_index == 0) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read dateTime %s; invalid seconds: %s", timevalue, token];
    }
    second = (NSUInteger) atof(token);
    if (timevalue[index] != '-') {
      index++;
    }
  }

  //go to ':' character.
  token_index = 0;
  while (index < len && timevalue[index] != ':') {
    token[token_index++] = timevalue[index++];
  }
  token[token_index] = '\0';
  offset_hour += atoi(token);
  index++;

  //go to end.
  token_index = 0;
  while (index < len) {
    token[token_index++] = timevalue[index++];
  }
  token[token_index] = '\0';
  offset_minute += atoi(token);

  //YYYY-MM-DD HH:MM:SS -HHHMM
  free(timevalue);
  return [NSDate dateWithString: [NSString stringWithFormat: @"%04i-%02i-%02i %02i:%02i:%02i %+03i%02i", year, month, day, hour, minute, second, offset_hour, offset_minute]];
}

/**
 * Read an XML type from an XML reader into an existing instance.
 *
 * @param reader The reader.
 * @param existing The existing instance into which to read values.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  [NSException raise: @"XMLReadError"
               format: @"An existing date cannot be modified."];
  return nil;
}

/**
 * Write the NSDate to the writer.
 *
 * @param writer The writer.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  NSDateFormatter *formatter = [[NSDateFormatter alloc] initWithDateFormat: @"%Y-%m-%dT%H:%M:%S %z" allowNaturalLanguage: NO];
  xmlChar *timevalue = BAD_CAST [[formatter stringForObjectValue: self] UTF8String];
  timevalue[19] = timevalue[20];
  timevalue[20] = timevalue[21];
  timevalue[21] = timevalue[22];
  timevalue[22] = ':';
  xmlTextWriterWriteString(writer, timevalue);
  [formatter release];
}
@end /*NSDate (JAXBType)*/

#endif /* ENUNCIATE_OBJC_CLASSES */

#ifndef ENUNCIATE_XML_OBJC_PRIMITIVE_FUNCTIONS
#define ENUNCIATE_XML_OBJC_PRIMITIVE_FUNCTIONS

/*******************boolean************************************/

/**
 * Read a boolean value from the reader.
 *
 * @param reader The reader (pointing at a node with a value).
 * @return YES if "true" was read. NO otherwise.
 */
static BOOL *xmlTextReaderReadBooleanType(xmlTextReaderPtr reader) {
  xmlChar *nodeValue = xmlTextReaderReadEntireNodeValue(reader);
  BOOL *value = malloc(sizeof(BOOL));
  *value = (xmlStrcmp(BAD_CAST "true", nodeValue) == 0) ? YES : NO;
  free(nodeValue);
  return value;
}

/**
 * Write a boolean value to the writer.
 *
 * @param writer The writer.
 * @param value The value to be written.
 * @return the bytes written (may be 0 because of buffering) or -1 in case of error.
 */
static int xmlTextWriterWriteBooleanType(xmlTextWriterPtr writer, BOOL *value) {
  if (*value) {
    return xmlTextWriterWriteString(writer, BAD_CAST "false");
  }
  else {
    return xmlTextWriterWriteString(writer, BAD_CAST "true");
  }
}

/*******************byte************************************/

/**
 * Read a byte value from the reader.
 *
 * @param reader The reader (pointing at a node with a value).
 * @return the byte.
 */
static unsigned char *xmlTextReaderReadByteType(xmlTextReaderPtr reader) {
  xmlChar *nodeValue = xmlTextReaderReadEntireNodeValue(reader);
  unsigned char *value = malloc(sizeof(unsigned char));
  *value = (unsigned char) atoi((char *) nodeValue);
  free(nodeValue);
  return value;
}

/**
 * Write a byte value to the writer.
 *
 * @param writer The writer.
 * @param value The value to be written.
 * @return the bytes written (may be 0 because of buffering) or -1 in case of error.
 */
static int xmlTextWriterWriteByteType(xmlTextWriterPtr writer, unsigned char *value) {
  return xmlTextWriterWriteFormatString(writer, "%i", *value);
}

/*******************double************************************/

/**
 * Read a double value from the reader.
 *
 * @param reader The reader (pointing at a node with a value).
 * @return the double.
 */
static double *xmlTextReaderReadDoubleType(xmlTextReaderPtr reader) {
  xmlChar *nodeValue = xmlTextReaderReadEntireNodeValue(reader);
  double *value = malloc(sizeof(double));
  *value = atof((char *) nodeValue);
  free(nodeValue);
  return value;
}

/**
 * Write a double value to the writer.
 *
 * @param writer The writer.
 * @param value The value to be written.
 * @return the bytes written (may be 0 because of buffering) or -1 in case of error.
 */
static int xmlTextWriterWriteDoubleType(xmlTextWriterPtr writer, double *value) {
  return xmlTextWriterWriteFormatString(writer, "%f", *value);
}

/*******************float************************************/

/**
 * Read a float value from the reader.
 *
 * @param reader The reader (pointing at a node with a value).
 * @return the float.
 */
static float *xmlTextReaderReadFloatType(xmlTextReaderPtr reader) {
  xmlChar *nodeValue = xmlTextReaderReadEntireNodeValue(reader);
  float *value = malloc(sizeof(float));
  *value = atof((char *)nodeValue);
  free(nodeValue);
  return value;
}

/**
 * Write a float value to the writer.
 *
 * @param writer The writer.
 * @param value The value to be written.
 * @return the bytes written (may be 0 because of buffering) or -1 in case of error.
 */
static int xmlTextWriterWriteFloatType(xmlTextWriterPtr writer, float *value) {
  return xmlTextWriterWriteFormatString(writer, "%f", *value);
}

/*******************int************************************/

/**
 * Read a int value from the reader.
 *
 * @param reader The reader (pointing at a node with a value).
 * @param value The value to be written.
 * @return the int.
 */
static int *xmlTextReaderReadIntType(xmlTextReaderPtr reader) {
  xmlChar *nodeValue = xmlTextReaderReadEntireNodeValue(reader);
  int *value = malloc(sizeof(int));
  *value = atoi((char *)nodeValue);
  free(nodeValue);
  return value;
}

/**
 * Write a int value to the writer.
 *
 * @param writer The writer.
 * @param value The value to be written.
 * @return the bytes written (may be 0 because of buffering) or -1 in case of error.
 */
static int xmlTextWriterWriteIntType(xmlTextWriterPtr writer, int *value) {
  return xmlTextWriterWriteFormatString(writer, "%i", *value);
}

/*******************long************************************/

/**
 * Read a long value from the reader.
 *
 * @param reader The reader (pointing at a node with a value).
 * @return the long.
 */
static long *xmlTextReaderReadLongType(xmlTextReaderPtr reader) {
  xmlChar *nodeValue = xmlTextReaderReadEntireNodeValue(reader);
  long *value = malloc(sizeof(long));
  *value = atol((char *)nodeValue);
  free(nodeValue);
  return value;
}

/**
 * Write a long value to the writer.
 *
 * @param writer The writer.
 * @param value The value to be written.
 * @return the bytes written (may be 0 because of buffering) or -1 in case of error.
 */
static int xmlTextWriterWriteLongType(xmlTextWriterPtr writer, long *value) {
  return xmlTextWriterWriteFormatString(writer, "%ld", *value);
}

/*******************short************************************/

/**
 * Read a short value from the reader.
 *
 * @param reader The reader (pointing at a node with a value).
 * @return the short.
 */
static short *xmlTextReaderReadShortType(xmlTextReaderPtr reader) {
  xmlChar *nodeValue = xmlTextReaderReadEntireNodeValue(reader);
  short *value = malloc(sizeof(short));
  *value = atoi((char *)nodeValue);
  free(nodeValue);
  return value;
}

/**
 * Write a short value to the writer.
 *
 * @param writer The writer.
 * @param value The value to be written.
 * @return the bytes written (may be 0 because of buffering) or -1 in case of error.
 */
static int xmlTextWriterWriteShortType(xmlTextWriterPtr writer, short *value) {
  return xmlTextWriterWriteFormatString(writer, "%hi", *value);
}

/*******************char************************************/

/**
 * Read a character value from the reader.
 *
 * @param reader The reader (pointing at a node with a value).
 * @return the character.
 */
static xmlChar *xmlTextReaderReadCharacterType(xmlTextReaderPtr reader) {
  return xmlTextReaderReadEntireNodeValue(reader);
}

/**
 * Write a character value to the writer.
 *
 * @param writer The writer.
 * @param value The value to be written.
 * @return the bytes written (may be 0 because of buffering) or -1 in case of error.
 */
static int xmlTextWriterWriteCharacterType(xmlTextWriterPtr writer, xmlChar *value) {
  return xmlTextWriterWriteString(writer, value);
}

#endif /* ENUNCIATE_XML_OBJC_PRIMITIVE_FUNCTIONS */

#ifndef DEF_NEXUS_REST_APINS0ErrorReportRequestDTO_M
#define DEF_NEXUS_REST_APINS0ErrorReportRequestDTO_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0ErrorReportRequestDTO

/**
 * (no documentation provided)
 */
- (NSString *) description
{
  return _description;
}

/**
 * (no documentation provided)
 */
- (void) setDescription: (NSString *) newDescription
{
  [newDescription retain];
  [_description release];
  _description = newDescription;
}

/**
 * (no documentation provided)
 */
- (NSString *) title
{
  return _title;
}

/**
 * (no documentation provided)
 */
- (void) setTitle: (NSString *) newTitle
{
  [newTitle retain];
  [_title release];
  _title = newTitle;
}

/**
 * (no documentation provided)
 */
- (BOOL) saveErrorReportingSettings
{
  return _saveErrorReportingSettings;
}

/**
 * (no documentation provided)
 */
- (void) setSaveErrorReportingSettings: (BOOL) newSaveErrorReportingSettings
{
  _saveErrorReportingSettings = newSaveErrorReportingSettings;
}

/**
 * (no documentation provided)
 */
- (NEXUS_REST_APINS0ErrorReportingSettings *) errorReportingSettings
{
  return _errorReportingSettings;
}

/**
 * (no documentation provided)
 */
- (void) setErrorReportingSettings: (NEXUS_REST_APINS0ErrorReportingSettings *) newErrorReportingSettings
{
  [newErrorReportingSettings retain];
  [_errorReportingSettings release];
  _errorReportingSettings = newErrorReportingSettings;
}

- (void) dealloc
{
  [self setDescription: nil];
  [self setTitle: nil];
  [self setErrorReportingSettings: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0ErrorReportRequestDTO */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0ErrorReportRequestDTO (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0ErrorReportRequestDTO (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0ErrorReportRequestDTO (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0ErrorReportRequestDTO from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0ErrorReportRequestDTO defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0ErrorReportRequestDTO *_nEXUS_REST_APINS0ErrorReportRequestDTO = [[NEXUS_REST_APINS0ErrorReportRequestDTO alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0ErrorReportRequestDTO initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0ErrorReportRequestDTO dealloc];
    _nEXUS_REST_APINS0ErrorReportRequestDTO = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0ErrorReportRequestDTO autorelease];
  return _nEXUS_REST_APINS0ErrorReportRequestDTO;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0ErrorReportRequestDTO according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0ErrorReportRequestDTO to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "description", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}description of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}description of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setDescription: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "title", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}title of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}title of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setTitle: __child];
    return YES;
  } //end "if choice"


  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "saveErrorReportingSettings", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setSaveErrorReportingSettings: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "errorReportingSettings", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}errorReportingSettings of type {}error-reporting-settings.");
#endif
    __child = [NEXUS_REST_APINS0ErrorReportingSettings readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}errorReportingSettings of type {}error-reporting-settings.");
#endif

    [self setErrorReportingSettings: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self description]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "description", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}description."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}description...");
#endif
    [[self description] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}description...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}description."];
    }
  }
  if ([self title]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "title", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}title."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}title...");
#endif
    [[self title] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}title...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}title."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "saveErrorReportingSettings", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}saveErrorReportingSettings."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}saveErrorReportingSettings...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_saveErrorReportingSettings);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}saveErrorReportingSettings...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}saveErrorReportingSettings."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}saveErrorReportingSettings."];
    }
  }
  if ([self errorReportingSettings]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "errorReportingSettings", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}errorReportingSettings."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}errorReportingSettings...");
#endif
    [[self errorReportingSettings] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}errorReportingSettings...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}errorReportingSettings."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0ErrorReportRequestDTO (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0ErrorReportRequestDTO_M */
#ifndef DEF_NEXUS_REST_APINS0GlobalConfigurationResource_M
#define DEF_NEXUS_REST_APINS0GlobalConfigurationResource_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0GlobalConfigurationResource

/**
 * (no documentation provided)
 */
- (BOOL) securityEnabled
{
  return _securityEnabled;
}

/**
 * (no documentation provided)
 */
- (void) setSecurityEnabled: (BOOL) newSecurityEnabled
{
  _securityEnabled = newSecurityEnabled;
}

/**
 * (no documentation provided)
 */
- (NEXUS_REST_APINS0RemoteConnectionSettings *) globalConnectionSettings
{
  return _globalConnectionSettings;
}

/**
 * (no documentation provided)
 */
- (void) setGlobalConnectionSettings: (NEXUS_REST_APINS0RemoteConnectionSettings *) newGlobalConnectionSettings
{
  [newGlobalConnectionSettings retain];
  [_globalConnectionSettings release];
  _globalConnectionSettings = newGlobalConnectionSettings;
}

/**
 * (no documentation provided)
 */
- (NEXUS_REST_APINS0RemoteHttpProxySettings *) globalHttpProxySettings
{
  return _globalHttpProxySettings;
}

/**
 * (no documentation provided)
 */
- (void) setGlobalHttpProxySettings: (NEXUS_REST_APINS0RemoteHttpProxySettings *) newGlobalHttpProxySettings
{
  [newGlobalHttpProxySettings retain];
  [_globalHttpProxySettings release];
  _globalHttpProxySettings = newGlobalHttpProxySettings;
}

/**
 * (no documentation provided)
 */
- (NSArray *) securityRealms
{
  return _securityRealms;
}

/**
 * (no documentation provided)
 */
- (void) setSecurityRealms: (NSArray *) newSecurityRealms
{
  [newSecurityRealms retain];
  [_securityRealms release];
  _securityRealms = newSecurityRealms;
}

/**
 * (no documentation provided)
 */
- (NSString *) securityAnonymousUsername
{
  return _securityAnonymousUsername;
}

/**
 * (no documentation provided)
 */
- (void) setSecurityAnonymousUsername: (NSString *) newSecurityAnonymousUsername
{
  [newSecurityAnonymousUsername retain];
  [_securityAnonymousUsername release];
  _securityAnonymousUsername = newSecurityAnonymousUsername;
}

/**
 * (no documentation provided)
 */
- (NEXUS_REST_APINS0SmtpSettings *) smtpSettings
{
  return _smtpSettings;
}

/**
 * (no documentation provided)
 */
- (void) setSmtpSettings: (NEXUS_REST_APINS0SmtpSettings *) newSmtpSettings
{
  [newSmtpSettings retain];
  [_smtpSettings release];
  _smtpSettings = newSmtpSettings;
}

/**
 * (no documentation provided)
 */
- (NSString *) securityAnonymousPassword
{
  return _securityAnonymousPassword;
}

/**
 * (no documentation provided)
 */
- (void) setSecurityAnonymousPassword: (NSString *) newSecurityAnonymousPassword
{
  [newSecurityAnonymousPassword retain];
  [_securityAnonymousPassword release];
  _securityAnonymousPassword = newSecurityAnonymousPassword;
}

/**
 * (no documentation provided)
 */
- (NEXUS_REST_APINS0RestApiSettings *) globalRestApiSettings
{
  return _globalRestApiSettings;
}

/**
 * (no documentation provided)
 */
- (void) setGlobalRestApiSettings: (NEXUS_REST_APINS0RestApiSettings *) newGlobalRestApiSettings
{
  [newGlobalRestApiSettings retain];
  [_globalRestApiSettings release];
  _globalRestApiSettings = newGlobalRestApiSettings;
}

/**
 * (no documentation provided)
 */
- (NEXUS_REST_APINS0ErrorReportingSettings *) errorReportingSettings
{
  return _errorReportingSettings;
}

/**
 * (no documentation provided)
 */
- (void) setErrorReportingSettings: (NEXUS_REST_APINS0ErrorReportingSettings *) newErrorReportingSettings
{
  [newErrorReportingSettings retain];
  [_errorReportingSettings release];
  _errorReportingSettings = newErrorReportingSettings;
}

/**
 * (no documentation provided)
 */
- (BOOL) securityAnonymousAccessEnabled
{
  return _securityAnonymousAccessEnabled;
}

/**
 * (no documentation provided)
 */
- (void) setSecurityAnonymousAccessEnabled: (BOOL) newSecurityAnonymousAccessEnabled
{
  _securityAnonymousAccessEnabled = newSecurityAnonymousAccessEnabled;
}

/**
 * (no documentation provided)
 */
- (NEXUS_REST_APINS0SystemNotificationSettings *) systemNotificationSettings
{
  return _systemNotificationSettings;
}

/**
 * (no documentation provided)
 */
- (void) setSystemNotificationSettings: (NEXUS_REST_APINS0SystemNotificationSettings *) newSystemNotificationSettings
{
  [newSystemNotificationSettings retain];
  [_systemNotificationSettings release];
  _systemNotificationSettings = newSystemNotificationSettings;
}

- (void) dealloc
{
  [self setGlobalConnectionSettings: nil];
  [self setGlobalHttpProxySettings: nil];
  [self setSecurityRealms: nil];
  [self setSecurityAnonymousUsername: nil];
  [self setSmtpSettings: nil];
  [self setSecurityAnonymousPassword: nil];
  [self setGlobalRestApiSettings: nil];
  [self setErrorReportingSettings: nil];
  [self setSystemNotificationSettings: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0GlobalConfigurationResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0GlobalConfigurationResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0GlobalConfigurationResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0GlobalConfigurationResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0GlobalConfigurationResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0GlobalConfigurationResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0GlobalConfigurationResource *_nEXUS_REST_APINS0GlobalConfigurationResource = [[NEXUS_REST_APINS0GlobalConfigurationResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0GlobalConfigurationResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0GlobalConfigurationResource dealloc];
    _nEXUS_REST_APINS0GlobalConfigurationResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0GlobalConfigurationResource autorelease];
  return _nEXUS_REST_APINS0GlobalConfigurationResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0GlobalConfigurationResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0GlobalConfigurationResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "securityEnabled", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setSecurityEnabled: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "globalConnectionSettings", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}globalConnectionSettings of type {}remote-connection-settings.");
#endif
    __child = [NEXUS_REST_APINS0RemoteConnectionSettings readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}globalConnectionSettings of type {}remote-connection-settings.");
#endif

    [self setGlobalConnectionSettings: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "globalHttpProxySettings", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}globalHttpProxySettings of type {}remote-http-proxy-settings.");
#endif
    __child = [NEXUS_REST_APINS0RemoteHttpProxySettings readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}globalHttpProxySettings of type {}remote-http-proxy-settings.");
#endif

    [self setGlobalHttpProxySettings: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "securityRealms", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}securityRealms...");
#endif
      //start wrapper element "{}securityRealms"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "securityRealmItem", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}securityRealmItem of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}securityRealmItem of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    if ([self securityRealms]) {
      [self setSecurityRealms: [[self securityRealms] arrayByAddingObject: __child]];
    }
    else {
      [self setSecurityRealms: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}securityRealms...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}securityRealms"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setSecurityRealms: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "securityAnonymousUsername", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}securityAnonymousUsername of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}securityAnonymousUsername of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setSecurityAnonymousUsername: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "smtpSettings", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}smtpSettings of type {}smtp-settings.");
#endif
    __child = [NEXUS_REST_APINS0SmtpSettings readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}smtpSettings of type {}smtp-settings.");
#endif

    [self setSmtpSettings: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "securityAnonymousPassword", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}securityAnonymousPassword of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}securityAnonymousPassword of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setSecurityAnonymousPassword: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "globalRestApiSettings", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}globalRestApiSettings of type {}rest-api-settings.");
#endif
    __child = [NEXUS_REST_APINS0RestApiSettings readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}globalRestApiSettings of type {}rest-api-settings.");
#endif

    [self setGlobalRestApiSettings: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "errorReportingSettings", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}errorReportingSettings of type {}error-reporting-settings.");
#endif
    __child = [NEXUS_REST_APINS0ErrorReportingSettings readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}errorReportingSettings of type {}error-reporting-settings.");
#endif

    [self setErrorReportingSettings: __child];
    return YES;
  } //end "if choice"


  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "securityAnonymousAccessEnabled", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setSecurityAnonymousAccessEnabled: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "systemNotificationSettings", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}systemNotificationSettings of type {}system-notification-settings.");
#endif
    __child = [NEXUS_REST_APINS0SystemNotificationSettings readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}systemNotificationSettings of type {}system-notification-settings.");
#endif

    [self setSystemNotificationSettings: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "securityEnabled", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}securityEnabled."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}securityEnabled...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_securityEnabled);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}securityEnabled...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}securityEnabled."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}securityEnabled."];
    }
  }
  if ([self globalConnectionSettings]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "globalConnectionSettings", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}globalConnectionSettings."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}globalConnectionSettings...");
#endif
    [[self globalConnectionSettings] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}globalConnectionSettings...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}globalConnectionSettings."];
    }
  }
  if ([self globalHttpProxySettings]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "globalHttpProxySettings", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}globalHttpProxySettings."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}globalHttpProxySettings...");
#endif
    [[self globalHttpProxySettings] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}globalHttpProxySettings...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}globalHttpProxySettings."];
    }
  }
  if ([self securityRealms]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "securityRealms", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}securityRealms."];
    }
    __enumerator = [[self securityRealms] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "securityRealmItem", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}securityRealmItem."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}securityRealmItem...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}securityRealmItem...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}securityRealmItem."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}securityRealms."];
    }
  }
  if ([self securityAnonymousUsername]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "securityAnonymousUsername", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}securityAnonymousUsername."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}securityAnonymousUsername...");
#endif
    [[self securityAnonymousUsername] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}securityAnonymousUsername...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}securityAnonymousUsername."];
    }
  }
  if ([self smtpSettings]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "smtpSettings", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}smtpSettings."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}smtpSettings...");
#endif
    [[self smtpSettings] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}smtpSettings...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}smtpSettings."];
    }
  }
  if ([self securityAnonymousPassword]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "securityAnonymousPassword", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}securityAnonymousPassword."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}securityAnonymousPassword...");
#endif
    [[self securityAnonymousPassword] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}securityAnonymousPassword...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}securityAnonymousPassword."];
    }
  }
  if ([self globalRestApiSettings]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "globalRestApiSettings", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}globalRestApiSettings."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}globalRestApiSettings...");
#endif
    [[self globalRestApiSettings] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}globalRestApiSettings...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}globalRestApiSettings."];
    }
  }
  if ([self errorReportingSettings]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "errorReportingSettings", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}errorReportingSettings."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}errorReportingSettings...");
#endif
    [[self errorReportingSettings] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}errorReportingSettings...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}errorReportingSettings."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "securityAnonymousAccessEnabled", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}securityAnonymousAccessEnabled."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}securityAnonymousAccessEnabled...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_securityAnonymousAccessEnabled);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}securityAnonymousAccessEnabled...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}securityAnonymousAccessEnabled."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}securityAnonymousAccessEnabled."];
    }
  }
  if ([self systemNotificationSettings]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "systemNotificationSettings", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}systemNotificationSettings."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}systemNotificationSettings...");
#endif
    [[self systemNotificationSettings] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}systemNotificationSettings...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}systemNotificationSettings."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0GlobalConfigurationResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0GlobalConfigurationResource_M */
#ifndef DEF_NEXUS_REST_APINS0LogConfigResource_M
#define DEF_NEXUS_REST_APINS0LogConfigResource_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0LogConfigResource

/**
 * (no documentation provided)
 */
- (NSString *) rootLoggerAppenders
{
  return _rootLoggerAppenders;
}

/**
 * (no documentation provided)
 */
- (void) setRootLoggerAppenders: (NSString *) newRootLoggerAppenders
{
  [newRootLoggerAppenders retain];
  [_rootLoggerAppenders release];
  _rootLoggerAppenders = newRootLoggerAppenders;
}

/**
 * (no documentation provided)
 */
- (NSString *) fileAppenderLocation
{
  return _fileAppenderLocation;
}

/**
 * (no documentation provided)
 */
- (void) setFileAppenderLocation: (NSString *) newFileAppenderLocation
{
  [newFileAppenderLocation retain];
  [_fileAppenderLocation release];
  _fileAppenderLocation = newFileAppenderLocation;
}

/**
 * (no documentation provided)
 */
- (NSString *) fileAppenderPattern
{
  return _fileAppenderPattern;
}

/**
 * (no documentation provided)
 */
- (void) setFileAppenderPattern: (NSString *) newFileAppenderPattern
{
  [newFileAppenderPattern retain];
  [_fileAppenderPattern release];
  _fileAppenderPattern = newFileAppenderPattern;
}

/**
 * (no documentation provided)
 */
- (NSString *) rootLoggerLevel
{
  return _rootLoggerLevel;
}

/**
 * (no documentation provided)
 */
- (void) setRootLoggerLevel: (NSString *) newRootLoggerLevel
{
  [newRootLoggerLevel retain];
  [_rootLoggerLevel release];
  _rootLoggerLevel = newRootLoggerLevel;
}

- (void) dealloc
{
  [self setRootLoggerAppenders: nil];
  [self setFileAppenderLocation: nil];
  [self setFileAppenderPattern: nil];
  [self setRootLoggerLevel: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0LogConfigResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0LogConfigResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0LogConfigResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0LogConfigResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0LogConfigResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0LogConfigResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0LogConfigResource *_nEXUS_REST_APINS0LogConfigResource = [[NEXUS_REST_APINS0LogConfigResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0LogConfigResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0LogConfigResource dealloc];
    _nEXUS_REST_APINS0LogConfigResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0LogConfigResource autorelease];
  return _nEXUS_REST_APINS0LogConfigResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0LogConfigResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0LogConfigResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "rootLoggerAppenders", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}rootLoggerAppenders of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}rootLoggerAppenders of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setRootLoggerAppenders: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "fileAppenderLocation", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}fileAppenderLocation of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}fileAppenderLocation of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setFileAppenderLocation: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "fileAppenderPattern", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}fileAppenderPattern of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}fileAppenderPattern of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setFileAppenderPattern: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "rootLoggerLevel", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}rootLoggerLevel of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}rootLoggerLevel of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setRootLoggerLevel: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self rootLoggerAppenders]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "rootLoggerAppenders", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}rootLoggerAppenders."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}rootLoggerAppenders...");
#endif
    [[self rootLoggerAppenders] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}rootLoggerAppenders...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}rootLoggerAppenders."];
    }
  }
  if ([self fileAppenderLocation]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "fileAppenderLocation", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}fileAppenderLocation."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}fileAppenderLocation...");
#endif
    [[self fileAppenderLocation] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}fileAppenderLocation...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}fileAppenderLocation."];
    }
  }
  if ([self fileAppenderPattern]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "fileAppenderPattern", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}fileAppenderPattern."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}fileAppenderPattern...");
#endif
    [[self fileAppenderPattern] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}fileAppenderPattern...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}fileAppenderPattern."];
    }
  }
  if ([self rootLoggerLevel]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "rootLoggerLevel", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}rootLoggerLevel."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}rootLoggerLevel...");
#endif
    [[self rootLoggerLevel] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}rootLoggerLevel...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}rootLoggerLevel."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0LogConfigResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0LogConfigResource_M */
#ifndef DEF_NEXUS_REST_APINS0MirrorResource_M
#define DEF_NEXUS_REST_APINS0MirrorResource_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0MirrorResource

/**
 * (no documentation provided)
 */
- (NSString *) id
{
  return _id;
}

/**
 * (no documentation provided)
 */
- (void) setId: (NSString *) newId
{
  [newId retain];
  [_id release];
  _id = newId;
}

/**
 * (no documentation provided)
 */
- (NSString *) url
{
  return _url;
}

/**
 * (no documentation provided)
 */
- (void) setUrl: (NSString *) newUrl
{
  [newUrl retain];
  [_url release];
  _url = newUrl;
}

- (void) dealloc
{
  [self setId: nil];
  [self setUrl: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0MirrorResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0MirrorResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0MirrorResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0MirrorResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0MirrorResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0MirrorResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0MirrorResource *_nEXUS_REST_APINS0MirrorResource = [[NEXUS_REST_APINS0MirrorResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0MirrorResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0MirrorResource dealloc];
    _nEXUS_REST_APINS0MirrorResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0MirrorResource autorelease];
  return _nEXUS_REST_APINS0MirrorResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0MirrorResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0MirrorResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "id", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "url", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}url of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}url of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setUrl: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self id]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "id", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}id."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}id...");
#endif
    [[self id] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}id...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}id."];
    }
  }
  if ([self url]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "url", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}url."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}url...");
#endif
    [[self url] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}url...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}url."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0MirrorResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0MirrorResource_M */
#ifndef DEF_NEXUS_REST_APINS0NexusResponse_M
#define DEF_NEXUS_REST_APINS0NexusResponse_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0NexusResponse

- (void) dealloc
{
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0NexusResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0NexusResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0NexusResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0NexusResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0NexusResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0NexusResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0NexusResponse *_nEXUS_REST_APINS0NexusResponse = [[NEXUS_REST_APINS0NexusResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0NexusResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0NexusResponse dealloc];
    _nEXUS_REST_APINS0NexusResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0NexusResponse autorelease];
  return _nEXUS_REST_APINS0NexusResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0NexusResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0NexusResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

}
@end /* implementation NEXUS_REST_APINS0NexusResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0NexusResponse_M */
#ifndef DEF_NEXUS_REST_APINS0PrivilegeResourceRequest_M
#define DEF_NEXUS_REST_APINS0PrivilegeResourceRequest_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0PrivilegeResourceRequest

/**
 * (no documentation provided)
 */
- (NEXUS_REST_APINS0PrivilegeResource *) data
{
  return _data;
}

/**
 * (no documentation provided)
 */
- (void) setData: (NEXUS_REST_APINS0PrivilegeResource *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0PrivilegeResourceRequest *_nEXUS_REST_APINS0PrivilegeResourceRequest;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0PrivilegeResourceRequest = (NEXUS_REST_APINS0PrivilegeResourceRequest *) [NEXUS_REST_APINS0PrivilegeResourceRequest readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0PrivilegeResourceRequest;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0PrivilegeResourceRequest */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0PrivilegeResourceRequest (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0PrivilegeResourceRequest (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0PrivilegeResourceRequest (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0PrivilegeResourceRequest from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0PrivilegeResourceRequest defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0PrivilegeResourceRequest *_nEXUS_REST_APINS0PrivilegeResourceRequest = [[NEXUS_REST_APINS0PrivilegeResourceRequest alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0PrivilegeResourceRequest initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0PrivilegeResourceRequest dealloc];
    _nEXUS_REST_APINS0PrivilegeResourceRequest = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0PrivilegeResourceRequest autorelease];
  return _nEXUS_REST_APINS0PrivilegeResourceRequest;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0PrivilegeResourceRequest according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0PrivilegeResourceRequest to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0PrivilegeResourceRequest from an XML reader. The element to be read is
 * "privilege-request".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0PrivilegeResourceRequest.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0PrivilegeResourceRequest *_privilegeResourceRequest = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element privilege-request."];
    }
  }

  if (xmlStrcmp(BAD_CAST "privilege-request", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}privilege-request.");
#endif
    _privilegeResourceRequest = (NEXUS_REST_APINS0PrivilegeResourceRequest *)[NEXUS_REST_APINS0PrivilegeResourceRequest readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}privilege-request.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0PrivilegeResourceRequest. Expected element privilege-request. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0PrivilegeResourceRequest. Expected element privilege-request. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _privilegeResourceRequest;
}

/**
 * Writes this NEXUS_REST_APINS0PrivilegeResourceRequest to XML under element name "privilege-request".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _privilegeResourceRequest The PrivilegeResourceRequest to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0PrivilegeResourceRequest to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "privilege-request", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}privilege-request. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}privilegeResourceRequest for root element {}privilege-request...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}privilegeResourceRequest for root element {}privilege-request...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}privilege-request. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}privilege.");
#endif
    __child = [NEXUS_REST_APINS0PrivilegeResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}privilege.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0PrivilegeResourceRequest (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0PrivilegeResourceRequest_M */
#ifndef DEF_NEXUS_REST_APINS0RemoteHttpProxySettings_M
#define DEF_NEXUS_REST_APINS0RemoteHttpProxySettings_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0RemoteHttpProxySettings

/**
 * (no documentation provided)
 */
- (NSArray *) nonProxyHosts
{
  return _nonProxyHosts;
}

/**
 * (no documentation provided)
 */
- (void) setNonProxyHosts: (NSArray *) newNonProxyHosts
{
  [newNonProxyHosts retain];
  [_nonProxyHosts release];
  _nonProxyHosts = newNonProxyHosts;
}

/**
 * (no documentation provided)
 */
- (int) proxyPort
{
  return _proxyPort;
}

/**
 * (no documentation provided)
 */
- (void) setProxyPort: (int) newProxyPort
{
  _proxyPort = newProxyPort;
}

/**
 * (no documentation provided)
 */
- (NEXUS_REST_APINS0AuthenticationSettings *) authentication
{
  return _authentication;
}

/**
 * (no documentation provided)
 */
- (void) setAuthentication: (NEXUS_REST_APINS0AuthenticationSettings *) newAuthentication
{
  [newAuthentication retain];
  [_authentication release];
  _authentication = newAuthentication;
}

/**
 * (no documentation provided)
 */
- (NSString *) proxyHostname
{
  return _proxyHostname;
}

/**
 * (no documentation provided)
 */
- (void) setProxyHostname: (NSString *) newProxyHostname
{
  [newProxyHostname retain];
  [_proxyHostname release];
  _proxyHostname = newProxyHostname;
}

- (void) dealloc
{
  [self setNonProxyHosts: nil];
  [self setAuthentication: nil];
  [self setProxyHostname: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0RemoteHttpProxySettings */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RemoteHttpProxySettings (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0RemoteHttpProxySettings (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RemoteHttpProxySettings (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RemoteHttpProxySettings from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RemoteHttpProxySettings defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RemoteHttpProxySettings *_nEXUS_REST_APINS0RemoteHttpProxySettings = [[NEXUS_REST_APINS0RemoteHttpProxySettings alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RemoteHttpProxySettings initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RemoteHttpProxySettings dealloc];
    _nEXUS_REST_APINS0RemoteHttpProxySettings = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RemoteHttpProxySettings autorelease];
  return _nEXUS_REST_APINS0RemoteHttpProxySettings;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RemoteHttpProxySettings according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RemoteHttpProxySettings to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "nonProxyHosts", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}nonProxyHosts of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}nonProxyHosts of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    if ([self nonProxyHosts]) {
      [self setNonProxyHosts: [[self nonProxyHosts] arrayByAddingObject: __child]];
    }
    else {
      [self setNonProxyHosts: [NSArray arrayWithObject: __child]];
    }
    return YES;
  } //end "if choice"


  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "proxyPort", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadIntType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setProxyPort: *((int*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "authentication", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}authentication of type {}authentication-settings.");
#endif
    __child = [NEXUS_REST_APINS0AuthenticationSettings readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}authentication of type {}authentication-settings.");
#endif

    [self setAuthentication: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "proxyHostname", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}proxyHostname of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}proxyHostname of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setProxyHostname: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self nonProxyHosts]) {
    __enumerator = [[self nonProxyHosts] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "nonProxyHosts", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}nonProxyHosts."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}nonProxyHosts...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}nonProxyHosts...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}nonProxyHosts."];
      }
    } //end item iterator.
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "proxyPort", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}proxyPort."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}proxyPort...");
#endif
    status = xmlTextWriterWriteIntType(writer, &_proxyPort);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}proxyPort...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}proxyPort."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}proxyPort."];
    }
  }
  if ([self authentication]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "authentication", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}authentication."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}authentication...");
#endif
    [[self authentication] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}authentication...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}authentication."];
    }
  }
  if ([self proxyHostname]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "proxyHostname", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}proxyHostname."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}proxyHostname...");
#endif
    [[self proxyHostname] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}proxyHostname...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}proxyHostname."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RemoteHttpProxySettings (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RemoteHttpProxySettings_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryDependentStatusResource_M
#define DEF_NEXUS_REST_APINS0RepositoryDependentStatusResource_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0RepositoryDependentStatusResource

/**
 * (no documentation provided)
 */
- (NSString *) localStatus
{
  return _localStatus;
}

/**
 * (no documentation provided)
 */
- (void) setLocalStatus: (NSString *) newLocalStatus
{
  [newLocalStatus retain];
  [_localStatus release];
  _localStatus = newLocalStatus;
}

/**
 * (no documentation provided)
 */
- (NSString *) format
{
  return _format;
}

/**
 * (no documentation provided)
 */
- (void) setFormat: (NSString *) newFormat
{
  [newFormat retain];
  [_format release];
  _format = newFormat;
}

/**
 * (no documentation provided)
 */
- (NSString *) repoType
{
  return _repoType;
}

/**
 * (no documentation provided)
 */
- (void) setRepoType: (NSString *) newRepoType
{
  [newRepoType retain];
  [_repoType release];
  _repoType = newRepoType;
}

/**
 * (no documentation provided)
 */
- (NSString *) id
{
  return _id;
}

/**
 * (no documentation provided)
 */
- (void) setId: (NSString *) newId
{
  [newId retain];
  [_id release];
  _id = newId;
}

- (void) dealloc
{
  [self setLocalStatus: nil];
  [self setFormat: nil];
  [self setRepoType: nil];
  [self setId: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0RepositoryDependentStatusResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryDependentStatusResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0RepositoryDependentStatusResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryDependentStatusResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryDependentStatusResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryDependentStatusResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryDependentStatusResource *_nEXUS_REST_APINS0RepositoryDependentStatusResource = [[NEXUS_REST_APINS0RepositoryDependentStatusResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryDependentStatusResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryDependentStatusResource dealloc];
    _nEXUS_REST_APINS0RepositoryDependentStatusResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryDependentStatusResource autorelease];
  return _nEXUS_REST_APINS0RepositoryDependentStatusResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryDependentStatusResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryDependentStatusResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "localStatus", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}localStatus of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}localStatus of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setLocalStatus: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "format", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}format of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}format of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setFormat: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "repoType", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}repoType of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}repoType of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setRepoType: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "id", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setId: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self localStatus]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "localStatus", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}localStatus."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}localStatus...");
#endif
    [[self localStatus] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}localStatus...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}localStatus."];
    }
  }
  if ([self format]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "format", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}format."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}format...");
#endif
    [[self format] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}format...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}format."];
    }
  }
  if ([self repoType]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repoType", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}repoType."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}repoType...");
#endif
    [[self repoType] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}repoType...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}repoType."];
    }
  }
  if ([self id]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "id", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}id."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}id...");
#endif
    [[self id] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}id...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}id."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryDependentStatusResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryDependentStatusResource_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryGroupMemberRepository_M
#define DEF_NEXUS_REST_APINS0RepositoryGroupMemberRepository_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0RepositoryGroupMemberRepository

/**
 * (no documentation provided)
 */
- (NSString *) resourceURI
{
  return _resourceURI;
}

/**
 * (no documentation provided)
 */
- (void) setResourceURI: (NSString *) newResourceURI
{
  [newResourceURI retain];
  [_resourceURI release];
  _resourceURI = newResourceURI;
}

/**
 * (no documentation provided)
 */
- (NSString *) id
{
  return _id;
}

/**
 * (no documentation provided)
 */
- (void) setId: (NSString *) newId
{
  [newId retain];
  [_id release];
  _id = newId;
}

/**
 * (no documentation provided)
 */
- (NSString *) name
{
  return _name;
}

/**
 * (no documentation provided)
 */
- (void) setName: (NSString *) newName
{
  [newName retain];
  [_name release];
  _name = newName;
}

- (void) dealloc
{
  [self setResourceURI: nil];
  [self setId: nil];
  [self setName: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0RepositoryGroupMemberRepository */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryGroupMemberRepository (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0RepositoryGroupMemberRepository (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryGroupMemberRepository (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryGroupMemberRepository from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryGroupMemberRepository defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryGroupMemberRepository *_nEXUS_REST_APINS0RepositoryGroupMemberRepository = [[NEXUS_REST_APINS0RepositoryGroupMemberRepository alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryGroupMemberRepository initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryGroupMemberRepository dealloc];
    _nEXUS_REST_APINS0RepositoryGroupMemberRepository = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryGroupMemberRepository autorelease];
  return _nEXUS_REST_APINS0RepositoryGroupMemberRepository;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryGroupMemberRepository according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryGroupMemberRepository to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "resourceURI", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setResourceURI: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "id", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "name", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setName: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self resourceURI]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "resourceURI", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}resourceURI."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}resourceURI...");
#endif
    [[self resourceURI] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}resourceURI...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}resourceURI."];
    }
  }
  if ([self id]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "id", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}id."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}id...");
#endif
    [[self id] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}id...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}id."];
    }
  }
  if ([self name]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "name", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}name."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}name...");
#endif
    [[self name] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}name...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}name."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryGroupMemberRepository (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryGroupMemberRepository_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryBaseResource_M
#define DEF_NEXUS_REST_APINS0RepositoryBaseResource_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0RepositoryBaseResource

/**
 * (no documentation provided)
 */
- (NSString *) id
{
  return _id;
}

/**
 * (no documentation provided)
 */
- (void) setId: (NSString *) newId
{
  [newId retain];
  [_id release];
  _id = newId;
}

/**
 * (no documentation provided)
 */
- (NSString *) name
{
  return _name;
}

/**
 * (no documentation provided)
 */
- (void) setName: (NSString *) newName
{
  [newName retain];
  [_name release];
  _name = newName;
}

/**
 * (no documentation provided)
 */
- (NSString *) provider
{
  return _provider;
}

/**
 * (no documentation provided)
 */
- (void) setProvider: (NSString *) newProvider
{
  [newProvider retain];
  [_provider release];
  _provider = newProvider;
}

/**
 * (no documentation provided)
 */
- (BOOL) exposed
{
  return _exposed;
}

/**
 * (no documentation provided)
 */
- (void) setExposed: (BOOL) newExposed
{
  _exposed = newExposed;
}

/**
 * (no documentation provided)
 */
- (NSString *) repoType
{
  return _repoType;
}

/**
 * (no documentation provided)
 */
- (void) setRepoType: (NSString *) newRepoType
{
  [newRepoType retain];
  [_repoType release];
  _repoType = newRepoType;
}

/**
 * (no documentation provided)
 */
- (NSString *) format
{
  return _format;
}

/**
 * (no documentation provided)
 */
- (void) setFormat: (NSString *) newFormat
{
  [newFormat retain];
  [_format release];
  _format = newFormat;
}

/**
 * (no documentation provided)
 */
- (NSString *) providerRole
{
  return _providerRole;
}

/**
 * (no documentation provided)
 */
- (void) setProviderRole: (NSString *) newProviderRole
{
  [newProviderRole retain];
  [_providerRole release];
  _providerRole = newProviderRole;
}

/**
 * (no documentation provided)
 */
- (NSString *) contentResourceURI
{
  return _contentResourceURI;
}

/**
 * (no documentation provided)
 */
- (void) setContentResourceURI: (NSString *) newContentResourceURI
{
  [newContentResourceURI retain];
  [_contentResourceURI release];
  _contentResourceURI = newContentResourceURI;
}

- (void) dealloc
{
  [self setId: nil];
  [self setName: nil];
  [self setProvider: nil];
  [self setRepoType: nil];
  [self setFormat: nil];
  [self setProviderRole: nil];
  [self setContentResourceURI: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0RepositoryBaseResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryBaseResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0RepositoryBaseResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryBaseResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryBaseResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryBaseResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryBaseResource *_nEXUS_REST_APINS0RepositoryBaseResource = [[NEXUS_REST_APINS0RepositoryBaseResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryBaseResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryBaseResource dealloc];
    _nEXUS_REST_APINS0RepositoryBaseResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryBaseResource autorelease];
  return _nEXUS_REST_APINS0RepositoryBaseResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryBaseResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryBaseResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "id", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "name", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setName: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "provider", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}provider of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}provider of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setProvider: __child];
    return YES;
  } //end "if choice"


  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "exposed", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setExposed: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "repoType", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}repoType of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}repoType of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setRepoType: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "format", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}format of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}format of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setFormat: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "providerRole", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}providerRole of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}providerRole of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setProviderRole: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "contentResourceURI", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}contentResourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}contentResourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setContentResourceURI: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self id]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "id", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}id."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}id...");
#endif
    [[self id] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}id...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}id."];
    }
  }
  if ([self name]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "name", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}name."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}name...");
#endif
    [[self name] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}name...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}name."];
    }
  }
  if ([self provider]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "provider", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}provider."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}provider...");
#endif
    [[self provider] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}provider...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}provider."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "exposed", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}exposed."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}exposed...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_exposed);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}exposed...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}exposed."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}exposed."];
    }
  }
  if ([self repoType]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repoType", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}repoType."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}repoType...");
#endif
    [[self repoType] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}repoType...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}repoType."];
    }
  }
  if ([self format]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "format", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}format."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}format...");
#endif
    [[self format] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}format...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}format."];
    }
  }
  if ([self providerRole]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "providerRole", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}providerRole."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}providerRole...");
#endif
    [[self providerRole] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}providerRole...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}providerRole."];
    }
  }
  if ([self contentResourceURI]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "contentResourceURI", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}contentResourceURI."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}contentResourceURI...");
#endif
    [[self contentResourceURI] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}contentResourceURI...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}contentResourceURI."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryBaseResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryBaseResource_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryRouteResource_M
#define DEF_NEXUS_REST_APINS0RepositoryRouteResource_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0RepositoryRouteResource

/**
 * (no documentation provided)
 */
- (NSString *) id
{
  return _id;
}

/**
 * (no documentation provided)
 */
- (void) setId: (NSString *) newId
{
  [newId retain];
  [_id release];
  _id = newId;
}

/**
 * (no documentation provided)
 */
- (NSString *) pattern
{
  return _pattern;
}

/**
 * (no documentation provided)
 */
- (void) setPattern: (NSString *) newPattern
{
  [newPattern retain];
  [_pattern release];
  _pattern = newPattern;
}

/**
 * (no documentation provided)
 */
- (NSArray *) repositories
{
  return _repositories;
}

/**
 * (no documentation provided)
 */
- (void) setRepositories: (NSArray *) newRepositories
{
  [newRepositories retain];
  [_repositories release];
  _repositories = newRepositories;
}

/**
 * (no documentation provided)
 */
- (NSString *) groupId
{
  return _groupId;
}

/**
 * (no documentation provided)
 */
- (void) setGroupId: (NSString *) newGroupId
{
  [newGroupId retain];
  [_groupId release];
  _groupId = newGroupId;
}

/**
 * (no documentation provided)
 */
- (NSString *) ruleType
{
  return _ruleType;
}

/**
 * (no documentation provided)
 */
- (void) setRuleType: (NSString *) newRuleType
{
  [newRuleType retain];
  [_ruleType release];
  _ruleType = newRuleType;
}

- (void) dealloc
{
  [self setId: nil];
  [self setPattern: nil];
  [self setRepositories: nil];
  [self setGroupId: nil];
  [self setRuleType: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0RepositoryRouteResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryRouteResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0RepositoryRouteResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryRouteResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryRouteResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryRouteResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryRouteResource *_nEXUS_REST_APINS0RepositoryRouteResource = [[NEXUS_REST_APINS0RepositoryRouteResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryRouteResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryRouteResource dealloc];
    _nEXUS_REST_APINS0RepositoryRouteResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryRouteResource autorelease];
  return _nEXUS_REST_APINS0RepositoryRouteResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryRouteResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryRouteResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "id", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "pattern", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}pattern of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}pattern of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setPattern: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "repositories", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}repositories...");
#endif
      //start wrapper element "{}repositories"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "repository", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}repository of type {}repository-route-member-repo.");
#endif

    __child = [NEXUS_REST_APINS0RepositoryRouteMemberRepository readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}repository of type {}repository-route-member-repo.");
#endif

    if ([self repositories]) {
      [self setRepositories: [[self repositories] arrayByAddingObject: __child]];
    }
    else {
      [self setRepositories: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}repositories...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}repositories"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setRepositories: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "groupId", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}groupId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}groupId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setGroupId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "ruleType", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}ruleType of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}ruleType of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setRuleType: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self id]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "id", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}id."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}id...");
#endif
    [[self id] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}id...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}id."];
    }
  }
  if ([self pattern]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "pattern", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}pattern."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}pattern...");
#endif
    [[self pattern] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}pattern...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}pattern."];
    }
  }
  if ([self repositories]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repositories", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}repositories."];
    }
    __enumerator = [[self repositories] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repository", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}repository."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}repository...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}repository...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}repository."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}repositories."];
    }
  }
  if ([self groupId]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "groupId", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}groupId."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}groupId...");
#endif
    [[self groupId] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}groupId...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}groupId."];
    }
  }
  if ([self ruleType]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "ruleType", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}ruleType."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}ruleType...");
#endif
    [[self ruleType] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}ruleType...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}ruleType."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryRouteResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryRouteResource_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryStatusResource_M
#define DEF_NEXUS_REST_APINS0RepositoryStatusResource_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0RepositoryStatusResource

/**
 * (no documentation provided)
 */
- (NSString *) format
{
  return _format;
}

/**
 * (no documentation provided)
 */
- (void) setFormat: (NSString *) newFormat
{
  [newFormat retain];
  [_format release];
  _format = newFormat;
}

/**
 * (no documentation provided)
 */
- (NSString *) proxyMode
{
  return _proxyMode;
}

/**
 * (no documentation provided)
 */
- (void) setProxyMode: (NSString *) newProxyMode
{
  [newProxyMode retain];
  [_proxyMode release];
  _proxyMode = newProxyMode;
}

/**
 * (no documentation provided)
 */
- (NSString *) repoType
{
  return _repoType;
}

/**
 * (no documentation provided)
 */
- (void) setRepoType: (NSString *) newRepoType
{
  [newRepoType retain];
  [_repoType release];
  _repoType = newRepoType;
}

/**
 * (no documentation provided)
 */
- (NSArray *) dependentRepos
{
  return _dependentRepos;
}

/**
 * (no documentation provided)
 */
- (void) setDependentRepos: (NSArray *) newDependentRepos
{
  [newDependentRepos retain];
  [_dependentRepos release];
  _dependentRepos = newDependentRepos;
}

/**
 * (no documentation provided)
 */
- (NSString *) remoteStatus
{
  return _remoteStatus;
}

/**
 * (no documentation provided)
 */
- (void) setRemoteStatus: (NSString *) newRemoteStatus
{
  [newRemoteStatus retain];
  [_remoteStatus release];
  _remoteStatus = newRemoteStatus;
}

/**
 * (no documentation provided)
 */
- (NSString *) localStatus
{
  return _localStatus;
}

/**
 * (no documentation provided)
 */
- (void) setLocalStatus: (NSString *) newLocalStatus
{
  [newLocalStatus retain];
  [_localStatus release];
  _localStatus = newLocalStatus;
}

/**
 * (no documentation provided)
 */
- (NSString *) id
{
  return _id;
}

/**
 * (no documentation provided)
 */
- (void) setId: (NSString *) newId
{
  [newId retain];
  [_id release];
  _id = newId;
}

- (void) dealloc
{
  [self setFormat: nil];
  [self setProxyMode: nil];
  [self setRepoType: nil];
  [self setDependentRepos: nil];
  [self setRemoteStatus: nil];
  [self setLocalStatus: nil];
  [self setId: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0RepositoryStatusResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryStatusResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0RepositoryStatusResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryStatusResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryStatusResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryStatusResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryStatusResource *_nEXUS_REST_APINS0RepositoryStatusResource = [[NEXUS_REST_APINS0RepositoryStatusResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryStatusResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryStatusResource dealloc];
    _nEXUS_REST_APINS0RepositoryStatusResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryStatusResource autorelease];
  return _nEXUS_REST_APINS0RepositoryStatusResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryStatusResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryStatusResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "format", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}format of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}format of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setFormat: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "proxyMode", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}proxyMode of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}proxyMode of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setProxyMode: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "repoType", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}repoType of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}repoType of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setRepoType: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "dependentRepos", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}dependentRepos...");
#endif
      //start wrapper element "{}dependentRepos"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "dependentRepoItem", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}dependentRepoItem of type {}repository-dependent-status.");
#endif

    __child = [NEXUS_REST_APINS0RepositoryDependentStatusResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}dependentRepoItem of type {}repository-dependent-status.");
#endif

    if ([self dependentRepos]) {
      [self setDependentRepos: [[self dependentRepos] arrayByAddingObject: __child]];
    }
    else {
      [self setDependentRepos: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}dependentRepos...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}dependentRepos"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setDependentRepos: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "remoteStatus", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}remoteStatus of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}remoteStatus of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setRemoteStatus: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "localStatus", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}localStatus of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}localStatus of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setLocalStatus: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "id", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setId: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self format]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "format", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}format."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}format...");
#endif
    [[self format] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}format...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}format."];
    }
  }
  if ([self proxyMode]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "proxyMode", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}proxyMode."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}proxyMode...");
#endif
    [[self proxyMode] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}proxyMode...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}proxyMode."];
    }
  }
  if ([self repoType]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repoType", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}repoType."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}repoType...");
#endif
    [[self repoType] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}repoType...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}repoType."];
    }
  }
  if ([self dependentRepos]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "dependentRepos", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}dependentRepos."];
    }
    __enumerator = [[self dependentRepos] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "dependentRepoItem", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}dependentRepoItem."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}dependentRepoItem...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}dependentRepoItem...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}dependentRepoItem."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}dependentRepos."];
    }
  }
  if ([self remoteStatus]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "remoteStatus", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}remoteStatus."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}remoteStatus...");
#endif
    [[self remoteStatus] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}remoteStatus...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}remoteStatus."];
    }
  }
  if ([self localStatus]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "localStatus", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}localStatus."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}localStatus...");
#endif
    [[self localStatus] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}localStatus...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}localStatus."];
    }
  }
  if ([self id]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "id", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}id."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}id...");
#endif
    [[self id] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}id...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}id."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryStatusResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryStatusResource_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryTargetResource_M
#define DEF_NEXUS_REST_APINS0RepositoryTargetResource_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0RepositoryTargetResource

/**
 * (no documentation provided)
 */
- (NSString *) id
{
  return _id;
}

/**
 * (no documentation provided)
 */
- (void) setId: (NSString *) newId
{
  [newId retain];
  [_id release];
  _id = newId;
}

/**
 * (no documentation provided)
 */
- (NSString *) resourceURI
{
  return _resourceURI;
}

/**
 * (no documentation provided)
 */
- (void) setResourceURI: (NSString *) newResourceURI
{
  [newResourceURI retain];
  [_resourceURI release];
  _resourceURI = newResourceURI;
}

/**
 * (no documentation provided)
 */
- (NSString *) name
{
  return _name;
}

/**
 * (no documentation provided)
 */
- (void) setName: (NSString *) newName
{
  [newName retain];
  [_name release];
  _name = newName;
}

/**
 * (no documentation provided)
 */
- (NSArray *) patterns
{
  return _patterns;
}

/**
 * (no documentation provided)
 */
- (void) setPatterns: (NSArray *) newPatterns
{
  [newPatterns retain];
  [_patterns release];
  _patterns = newPatterns;
}

/**
 * (no documentation provided)
 */
- (NSString *) contentClass
{
  return _contentClass;
}

/**
 * (no documentation provided)
 */
- (void) setContentClass: (NSString *) newContentClass
{
  [newContentClass retain];
  [_contentClass release];
  _contentClass = newContentClass;
}

- (void) dealloc
{
  [self setId: nil];
  [self setResourceURI: nil];
  [self setName: nil];
  [self setPatterns: nil];
  [self setContentClass: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0RepositoryTargetResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryTargetResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0RepositoryTargetResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryTargetResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryTargetResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryTargetResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryTargetResource *_nEXUS_REST_APINS0RepositoryTargetResource = [[NEXUS_REST_APINS0RepositoryTargetResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryTargetResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryTargetResource dealloc];
    _nEXUS_REST_APINS0RepositoryTargetResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryTargetResource autorelease];
  return _nEXUS_REST_APINS0RepositoryTargetResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryTargetResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryTargetResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "id", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "resourceURI", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setResourceURI: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "name", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setName: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "patterns", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}patterns...");
#endif
      //start wrapper element "{}patterns"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "pattern", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}pattern of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}pattern of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    if ([self patterns]) {
      [self setPatterns: [[self patterns] arrayByAddingObject: __child]];
    }
    else {
      [self setPatterns: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}patterns...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}patterns"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setPatterns: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "contentClass", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}contentClass of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}contentClass of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setContentClass: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self id]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "id", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}id."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}id...");
#endif
    [[self id] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}id...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}id."];
    }
  }
  if ([self resourceURI]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "resourceURI", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}resourceURI."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}resourceURI...");
#endif
    [[self resourceURI] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}resourceURI...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}resourceURI."];
    }
  }
  if ([self name]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "name", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}name."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}name...");
#endif
    [[self name] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}name...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}name."];
    }
  }
  if ([self patterns]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "patterns", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}patterns."];
    }
    __enumerator = [[self patterns] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "pattern", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}pattern."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}pattern...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}pattern...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}pattern."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}patterns."];
    }
  }
  if ([self contentClass]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "contentClass", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}contentClass."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}contentClass...");
#endif
    [[self contentClass] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}contentClass...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}contentClass."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryTargetResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryTargetResource_M */
#ifndef DEF_NEXUS_REST_APINS0RestApiSettings_M
#define DEF_NEXUS_REST_APINS0RestApiSettings_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0RestApiSettings

/**
 * (no documentation provided)
 */
- (int) uiTimeout
{
  return _uiTimeout;
}

/**
 * (no documentation provided)
 */
- (void) setUiTimeout: (int) newUiTimeout
{
  _uiTimeout = newUiTimeout;
}

/**
 * (no documentation provided)
 */
- (BOOL) forceBaseUrl
{
  return _forceBaseUrl;
}

/**
 * (no documentation provided)
 */
- (void) setForceBaseUrl: (BOOL) newForceBaseUrl
{
  _forceBaseUrl = newForceBaseUrl;
}

/**
 * (no documentation provided)
 */
- (NSString *) baseUrl
{
  return _baseUrl;
}

/**
 * (no documentation provided)
 */
- (void) setBaseUrl: (NSString *) newBaseUrl
{
  [newBaseUrl retain];
  [_baseUrl release];
  _baseUrl = newBaseUrl;
}

- (void) dealloc
{
  [self setBaseUrl: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0RestApiSettings */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RestApiSettings (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0RestApiSettings (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RestApiSettings (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RestApiSettings from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RestApiSettings defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RestApiSettings *_nEXUS_REST_APINS0RestApiSettings = [[NEXUS_REST_APINS0RestApiSettings alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RestApiSettings initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RestApiSettings dealloc];
    _nEXUS_REST_APINS0RestApiSettings = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RestApiSettings autorelease];
  return _nEXUS_REST_APINS0RestApiSettings;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RestApiSettings according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RestApiSettings to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "uiTimeout", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadIntType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setUiTimeout: *((int*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "forceBaseUrl", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setForceBaseUrl: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "baseUrl", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}baseUrl of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}baseUrl of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setBaseUrl: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "uiTimeout", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}uiTimeout."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}uiTimeout...");
#endif
    status = xmlTextWriterWriteIntType(writer, &_uiTimeout);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}uiTimeout...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}uiTimeout."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}uiTimeout."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "forceBaseUrl", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}forceBaseUrl."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}forceBaseUrl...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_forceBaseUrl);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}forceBaseUrl...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}forceBaseUrl."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}forceBaseUrl."];
    }
  }
  if ([self baseUrl]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "baseUrl", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}baseUrl."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}baseUrl...");
#endif
    [[self baseUrl] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}baseUrl...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}baseUrl."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RestApiSettings (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RestApiSettings_M */
#ifndef DEF_NEXUS_REST_APINS0ScheduledServicePropertyResource_M
#define DEF_NEXUS_REST_APINS0ScheduledServicePropertyResource_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0ScheduledServicePropertyResource

/**
 * (no documentation provided)
 */
- (NSString *) key
{
  return _key;
}

/**
 * (no documentation provided)
 */
- (void) setKey: (NSString *) newKey
{
  [newKey retain];
  [_key release];
  _key = newKey;
}

/**
 * (no documentation provided)
 */
- (NSString *) value
{
  return _value;
}

/**
 * (no documentation provided)
 */
- (void) setValue: (NSString *) newValue
{
  [newValue retain];
  [_value release];
  _value = newValue;
}

- (void) dealloc
{
  [self setKey: nil];
  [self setValue: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0ScheduledServicePropertyResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0ScheduledServicePropertyResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0ScheduledServicePropertyResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0ScheduledServicePropertyResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0ScheduledServicePropertyResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0ScheduledServicePropertyResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0ScheduledServicePropertyResource *_nEXUS_REST_APINS0ScheduledServicePropertyResource = [[NEXUS_REST_APINS0ScheduledServicePropertyResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0ScheduledServicePropertyResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0ScheduledServicePropertyResource dealloc];
    _nEXUS_REST_APINS0ScheduledServicePropertyResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0ScheduledServicePropertyResource autorelease];
  return _nEXUS_REST_APINS0ScheduledServicePropertyResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0ScheduledServicePropertyResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0ScheduledServicePropertyResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "key", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}key of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}key of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setKey: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "value", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}value of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}value of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setValue: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self key]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "key", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}key."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}key...");
#endif
    [[self key] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}key...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}key."];
    }
  }
  if ([self value]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "value", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}value."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}value...");
#endif
    [[self value] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}value...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}value."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0ScheduledServicePropertyResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0ScheduledServicePropertyResource_M */
#ifndef DEF_NEXUS_REST_APINS0SmtpSettings_M
#define DEF_NEXUS_REST_APINS0SmtpSettings_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0SmtpSettings

/**
 * (no documentation provided)
 */
- (NSString *) password
{
  return _password;
}

/**
 * (no documentation provided)
 */
- (void) setPassword: (NSString *) newPassword
{
  [newPassword retain];
  [_password release];
  _password = newPassword;
}

/**
 * (no documentation provided)
 */
- (NSString *) host
{
  return _host;
}

/**
 * (no documentation provided)
 */
- (void) setHost: (NSString *) newHost
{
  [newHost retain];
  [_host release];
  _host = newHost;
}

/**
 * (no documentation provided)
 */
- (NSString *) systemEmailAddress
{
  return _systemEmailAddress;
}

/**
 * (no documentation provided)
 */
- (void) setSystemEmailAddress: (NSString *) newSystemEmailAddress
{
  [newSystemEmailAddress retain];
  [_systemEmailAddress release];
  _systemEmailAddress = newSystemEmailAddress;
}

/**
 * (no documentation provided)
 */
- (NSString *) username
{
  return _username;
}

/**
 * (no documentation provided)
 */
- (void) setUsername: (NSString *) newUsername
{
  [newUsername retain];
  [_username release];
  _username = newUsername;
}

/**
 * (no documentation provided)
 */
- (int) port
{
  return _port;
}

/**
 * (no documentation provided)
 */
- (void) setPort: (int) newPort
{
  _port = newPort;
}

/**
 * (no documentation provided)
 */
- (BOOL) tlsEnabled
{
  return _tlsEnabled;
}

/**
 * (no documentation provided)
 */
- (void) setTlsEnabled: (BOOL) newTlsEnabled
{
  _tlsEnabled = newTlsEnabled;
}

/**
 * (no documentation provided)
 */
- (BOOL) sslEnabled
{
  return _sslEnabled;
}

/**
 * (no documentation provided)
 */
- (void) setSslEnabled: (BOOL) newSslEnabled
{
  _sslEnabled = newSslEnabled;
}

- (void) dealloc
{
  [self setPassword: nil];
  [self setHost: nil];
  [self setSystemEmailAddress: nil];
  [self setUsername: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0SmtpSettings */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0SmtpSettings (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0SmtpSettings (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0SmtpSettings (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0SmtpSettings from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0SmtpSettings defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0SmtpSettings *_nEXUS_REST_APINS0SmtpSettings = [[NEXUS_REST_APINS0SmtpSettings alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0SmtpSettings initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0SmtpSettings dealloc];
    _nEXUS_REST_APINS0SmtpSettings = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0SmtpSettings autorelease];
  return _nEXUS_REST_APINS0SmtpSettings;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0SmtpSettings according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0SmtpSettings to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "password", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}password of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}password of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setPassword: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "host", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}host of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}host of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setHost: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "systemEmailAddress", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}systemEmailAddress of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}systemEmailAddress of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setSystemEmailAddress: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "username", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}username of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}username of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setUsername: __child];
    return YES;
  } //end "if choice"


  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "port", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadIntType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setPort: *((int*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "tlsEnabled", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setTlsEnabled: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "sslEnabled", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setSslEnabled: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self password]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "password", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}password."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}password...");
#endif
    [[self password] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}password...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}password."];
    }
  }
  if ([self host]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "host", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}host."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}host...");
#endif
    [[self host] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}host...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}host."];
    }
  }
  if ([self systemEmailAddress]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "systemEmailAddress", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}systemEmailAddress."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}systemEmailAddress...");
#endif
    [[self systemEmailAddress] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}systemEmailAddress...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}systemEmailAddress."];
    }
  }
  if ([self username]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "username", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}username."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}username...");
#endif
    [[self username] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}username...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}username."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "port", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}port."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}port...");
#endif
    status = xmlTextWriterWriteIntType(writer, &_port);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}port...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}port."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}port."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "tlsEnabled", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}tlsEnabled."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}tlsEnabled...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_tlsEnabled);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}tlsEnabled...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}tlsEnabled."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}tlsEnabled."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "sslEnabled", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}sslEnabled."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}sslEnabled...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_sslEnabled);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}sslEnabled...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}sslEnabled."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}sslEnabled."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0SmtpSettings (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0SmtpSettings_M */
#ifndef DEF_NEXUS_REST_APINS0SmtpSettingsResource_M
#define DEF_NEXUS_REST_APINS0SmtpSettingsResource_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0SmtpSettingsResource

/**
 * (no documentation provided)
 */
- (NSString *) testEmail
{
  return _testEmail;
}

/**
 * (no documentation provided)
 */
- (void) setTestEmail: (NSString *) newTestEmail
{
  [newTestEmail retain];
  [_testEmail release];
  _testEmail = newTestEmail;
}

/**
 * (no documentation provided)
 */
- (NSString *) host
{
  return _host;
}

/**
 * (no documentation provided)
 */
- (void) setHost: (NSString *) newHost
{
  [newHost retain];
  [_host release];
  _host = newHost;
}

/**
 * (no documentation provided)
 */
- (NSString *) password
{
  return _password;
}

/**
 * (no documentation provided)
 */
- (void) setPassword: (NSString *) newPassword
{
  [newPassword retain];
  [_password release];
  _password = newPassword;
}

/**
 * (no documentation provided)
 */
- (BOOL) tlsEnabled
{
  return _tlsEnabled;
}

/**
 * (no documentation provided)
 */
- (void) setTlsEnabled: (BOOL) newTlsEnabled
{
  _tlsEnabled = newTlsEnabled;
}

/**
 * (no documentation provided)
 */
- (NSString *) systemEmailAddress
{
  return _systemEmailAddress;
}

/**
 * (no documentation provided)
 */
- (void) setSystemEmailAddress: (NSString *) newSystemEmailAddress
{
  [newSystemEmailAddress retain];
  [_systemEmailAddress release];
  _systemEmailAddress = newSystemEmailAddress;
}

/**
 * (no documentation provided)
 */
- (BOOL) sslEnabled
{
  return _sslEnabled;
}

/**
 * (no documentation provided)
 */
- (void) setSslEnabled: (BOOL) newSslEnabled
{
  _sslEnabled = newSslEnabled;
}

/**
 * (no documentation provided)
 */
- (NSString *) username
{
  return _username;
}

/**
 * (no documentation provided)
 */
- (void) setUsername: (NSString *) newUsername
{
  [newUsername retain];
  [_username release];
  _username = newUsername;
}

/**
 * (no documentation provided)
 */
- (int) port
{
  return _port;
}

/**
 * (no documentation provided)
 */
- (void) setPort: (int) newPort
{
  _port = newPort;
}

- (void) dealloc
{
  [self setTestEmail: nil];
  [self setHost: nil];
  [self setPassword: nil];
  [self setSystemEmailAddress: nil];
  [self setUsername: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0SmtpSettingsResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0SmtpSettingsResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0SmtpSettingsResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0SmtpSettingsResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0SmtpSettingsResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0SmtpSettingsResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0SmtpSettingsResource *_nEXUS_REST_APINS0SmtpSettingsResource = [[NEXUS_REST_APINS0SmtpSettingsResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0SmtpSettingsResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0SmtpSettingsResource dealloc];
    _nEXUS_REST_APINS0SmtpSettingsResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0SmtpSettingsResource autorelease];
  return _nEXUS_REST_APINS0SmtpSettingsResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0SmtpSettingsResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0SmtpSettingsResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "testEmail", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}testEmail of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}testEmail of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setTestEmail: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "host", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}host of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}host of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setHost: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "password", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}password of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}password of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setPassword: __child];
    return YES;
  } //end "if choice"


  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "tlsEnabled", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setTlsEnabled: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "systemEmailAddress", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}systemEmailAddress of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}systemEmailAddress of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setSystemEmailAddress: __child];
    return YES;
  } //end "if choice"


  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "sslEnabled", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setSslEnabled: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "username", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}username of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}username of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setUsername: __child];
    return YES;
  } //end "if choice"


  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "port", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadIntType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setPort: *((int*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self testEmail]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "testEmail", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}testEmail."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}testEmail...");
#endif
    [[self testEmail] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}testEmail...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}testEmail."];
    }
  }
  if ([self host]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "host", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}host."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}host...");
#endif
    [[self host] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}host...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}host."];
    }
  }
  if ([self password]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "password", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}password."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}password...");
#endif
    [[self password] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}password...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}password."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "tlsEnabled", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}tlsEnabled."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}tlsEnabled...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_tlsEnabled);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}tlsEnabled...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}tlsEnabled."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}tlsEnabled."];
    }
  }
  if ([self systemEmailAddress]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "systemEmailAddress", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}systemEmailAddress."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}systemEmailAddress...");
#endif
    [[self systemEmailAddress] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}systemEmailAddress...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}systemEmailAddress."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "sslEnabled", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}sslEnabled."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}sslEnabled...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_sslEnabled);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}sslEnabled...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}sslEnabled."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}sslEnabled."];
    }
  }
  if ([self username]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "username", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}username."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}username...");
#endif
    [[self username] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}username...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}username."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "port", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}port."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}port...");
#endif
    status = xmlTextWriterWriteIntType(writer, &_port);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}port...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}port."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}port."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0SmtpSettingsResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0SmtpSettingsResource_M */
#ifndef DEF_NEXUS_REST_APINS0UserAccount_M
#define DEF_NEXUS_REST_APINS0UserAccount_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0UserAccount

/**
 * (no documentation provided)
 */
- (NSString *) firstName
{
  return _firstName;
}

/**
 * (no documentation provided)
 */
- (void) setFirstName: (NSString *) newFirstName
{
  [newFirstName retain];
  [_firstName release];
  _firstName = newFirstName;
}

/**
 * (no documentation provided)
 */
- (NSString *) userId
{
  return _userId;
}

/**
 * (no documentation provided)
 */
- (void) setUserId: (NSString *) newUserId
{
  [newUserId retain];
  [_userId release];
  _userId = newUserId;
}

/**
 * (no documentation provided)
 */
- (NSString *) lastName
{
  return _lastName;
}

/**
 * (no documentation provided)
 */
- (void) setLastName: (NSString *) newLastName
{
  [newLastName retain];
  [_lastName release];
  _lastName = newLastName;
}

/**
 * (no documentation provided)
 */
- (NSString *) email
{
  return _email;
}

/**
 * (no documentation provided)
 */
- (void) setEmail: (NSString *) newEmail
{
  [newEmail retain];
  [_email release];
  _email = newEmail;
}

- (void) dealloc
{
  [self setFirstName: nil];
  [self setUserId: nil];
  [self setLastName: nil];
  [self setEmail: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0UserAccount */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0UserAccount (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0UserAccount (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0UserAccount (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0UserAccount from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0UserAccount defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0UserAccount *_nEXUS_REST_APINS0UserAccount = [[NEXUS_REST_APINS0UserAccount alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0UserAccount initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0UserAccount dealloc];
    _nEXUS_REST_APINS0UserAccount = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0UserAccount autorelease];
  return _nEXUS_REST_APINS0UserAccount;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0UserAccount according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0UserAccount to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "firstName", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}firstName of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}firstName of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setFirstName: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "userId", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}userId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}userId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setUserId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "lastName", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}lastName of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}lastName of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setLastName: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "email", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}email of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}email of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setEmail: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self firstName]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "firstName", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}firstName."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}firstName...");
#endif
    [[self firstName] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}firstName...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}firstName."];
    }
  }
  if ([self userId]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "userId", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}userId."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}userId...");
#endif
    [[self userId] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}userId...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}userId."];
    }
  }
  if ([self lastName]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "lastName", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}lastName."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}lastName...");
#endif
    [[self lastName] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}lastName...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}lastName."];
    }
  }
  if ([self email]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "email", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}email."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}email...");
#endif
    [[self email] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}email...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}email."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0UserAccount (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0UserAccount_M */
#ifndef DEF_NEXUS_REST_APINS0UserAccountRequestResponseWrapper_M
#define DEF_NEXUS_REST_APINS0UserAccountRequestResponseWrapper_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0UserAccountRequestResponseWrapper

/**
 * (no documentation provided)
 */
- (NEXUS_REST_APINS0UserAccount *) data
{
  return _data;
}

/**
 * (no documentation provided)
 */
- (void) setData: (NEXUS_REST_APINS0UserAccount *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0UserAccountRequestResponseWrapper *_nEXUS_REST_APINS0UserAccountRequestResponseWrapper;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0UserAccountRequestResponseWrapper = (NEXUS_REST_APINS0UserAccountRequestResponseWrapper *) [NEXUS_REST_APINS0UserAccountRequestResponseWrapper readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0UserAccountRequestResponseWrapper;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0UserAccountRequestResponseWrapper */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0UserAccountRequestResponseWrapper (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0UserAccountRequestResponseWrapper (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0UserAccountRequestResponseWrapper (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0UserAccountRequestResponseWrapper from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0UserAccountRequestResponseWrapper defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0UserAccountRequestResponseWrapper *_nEXUS_REST_APINS0UserAccountRequestResponseWrapper = [[NEXUS_REST_APINS0UserAccountRequestResponseWrapper alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0UserAccountRequestResponseWrapper initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0UserAccountRequestResponseWrapper dealloc];
    _nEXUS_REST_APINS0UserAccountRequestResponseWrapper = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0UserAccountRequestResponseWrapper autorelease];
  return _nEXUS_REST_APINS0UserAccountRequestResponseWrapper;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0UserAccountRequestResponseWrapper according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0UserAccountRequestResponseWrapper to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0UserAccountRequestResponseWrapper from an XML reader. The element to be read is
 * "user-account-request".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0UserAccountRequestResponseWrapper.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0UserAccountRequestResponseWrapper *_userAccountRequestResponseWrapper = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element user-account-request."];
    }
  }

  if (xmlStrcmp(BAD_CAST "user-account-request", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}user-account-request.");
#endif
    _userAccountRequestResponseWrapper = (NEXUS_REST_APINS0UserAccountRequestResponseWrapper *)[NEXUS_REST_APINS0UserAccountRequestResponseWrapper readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}user-account-request.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0UserAccountRequestResponseWrapper. Expected element user-account-request. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0UserAccountRequestResponseWrapper. Expected element user-account-request. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _userAccountRequestResponseWrapper;
}

/**
 * Writes this NEXUS_REST_APINS0UserAccountRequestResponseWrapper to XML under element name "user-account-request".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _userAccountRequestResponseWrapper The UserAccountRequestResponseWrapper to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0UserAccountRequestResponseWrapper to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "user-account-request", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}user-account-request. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}userAccountRequestResponseWrapper for root element {}user-account-request...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}userAccountRequestResponseWrapper for root element {}user-account-request...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}user-account-request. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}userAccount.");
#endif
    __child = [NEXUS_REST_APINS0UserAccount readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}userAccount.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0UserAccountRequestResponseWrapper (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0UserAccountRequestResponseWrapper_M */
#ifndef DEF_NEXUS_REST_APINS0SystemNotificationSettings_M
#define DEF_NEXUS_REST_APINS0SystemNotificationSettings_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0SystemNotificationSettings

/**
 * (no documentation provided)
 */
- (NSArray *) roles
{
  return _roles;
}

/**
 * (no documentation provided)
 */
- (void) setRoles: (NSArray *) newRoles
{
  [newRoles retain];
  [_roles release];
  _roles = newRoles;
}

/**
 * (no documentation provided)
 */
- (NSString *) emailAddresses
{
  return _emailAddresses;
}

/**
 * (no documentation provided)
 */
- (void) setEmailAddresses: (NSString *) newEmailAddresses
{
  [newEmailAddresses retain];
  [_emailAddresses release];
  _emailAddresses = newEmailAddresses;
}

/**
 * (no documentation provided)
 */
- (BOOL) enabled
{
  return _enabled;
}

/**
 * (no documentation provided)
 */
- (void) setEnabled: (BOOL) newEnabled
{
  _enabled = newEnabled;
}

- (void) dealloc
{
  [self setRoles: nil];
  [self setEmailAddresses: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0SystemNotificationSettings */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0SystemNotificationSettings (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0SystemNotificationSettings (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0SystemNotificationSettings (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0SystemNotificationSettings from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0SystemNotificationSettings defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0SystemNotificationSettings *_nEXUS_REST_APINS0SystemNotificationSettings = [[NEXUS_REST_APINS0SystemNotificationSettings alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0SystemNotificationSettings initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0SystemNotificationSettings dealloc];
    _nEXUS_REST_APINS0SystemNotificationSettings = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0SystemNotificationSettings autorelease];
  return _nEXUS_REST_APINS0SystemNotificationSettings;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0SystemNotificationSettings according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0SystemNotificationSettings to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "roles", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}roles of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}roles of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    if ([self roles]) {
      [self setRoles: [[self roles] arrayByAddingObject: __child]];
    }
    else {
      [self setRoles: [NSArray arrayWithObject: __child]];
    }
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "emailAddresses", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}emailAddresses of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}emailAddresses of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setEmailAddresses: __child];
    return YES;
  } //end "if choice"


  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "enabled", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setEnabled: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self roles]) {
    __enumerator = [[self roles] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "roles", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}roles."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}roles...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}roles...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}roles."];
      }
    } //end item iterator.
  }
  if ([self emailAddresses]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "emailAddresses", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}emailAddresses."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}emailAddresses...");
#endif
    [[self emailAddresses] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}emailAddresses...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}emailAddresses."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "enabled", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}enabled."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}enabled...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_enabled);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}enabled...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}enabled."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}enabled."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0SystemNotificationSettings (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0SystemNotificationSettings_M */
#ifndef DEF_NEXUS_REST_APINS0ScheduledServiceBaseResource_M
#define DEF_NEXUS_REST_APINS0ScheduledServiceBaseResource_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0ScheduledServiceBaseResource

/**
 * (no documentation provided)
 */
- (NSString *) name
{
  return _name;
}

/**
 * (no documentation provided)
 */
- (void) setName: (NSString *) newName
{
  [newName retain];
  [_name release];
  _name = newName;
}

/**
 * (no documentation provided)
 */
- (NSString *) schedule
{
  return _schedule;
}

/**
 * (no documentation provided)
 */
- (void) setSchedule: (NSString *) newSchedule
{
  [newSchedule retain];
  [_schedule release];
  _schedule = newSchedule;
}

/**
 * (no documentation provided)
 */
- (NSString *) alertEmail
{
  return _alertEmail;
}

/**
 * (no documentation provided)
 */
- (void) setAlertEmail: (NSString *) newAlertEmail
{
  [newAlertEmail retain];
  [_alertEmail release];
  _alertEmail = newAlertEmail;
}

/**
 * (no documentation provided)
 */
- (NSArray *) properties
{
  return _properties;
}

/**
 * (no documentation provided)
 */
- (void) setProperties: (NSArray *) newProperties
{
  [newProperties retain];
  [_properties release];
  _properties = newProperties;
}

/**
 * (no documentation provided)
 */
- (NSString *) id
{
  return _id;
}

/**
 * (no documentation provided)
 */
- (void) setId: (NSString *) newId
{
  [newId retain];
  [_id release];
  _id = newId;
}

/**
 * (no documentation provided)
 */
- (BOOL) enabled
{
  return _enabled;
}

/**
 * (no documentation provided)
 */
- (void) setEnabled: (BOOL) newEnabled
{
  _enabled = newEnabled;
}

/**
 * (no documentation provided)
 */
- (NSString *) typeId
{
  return _typeId;
}

/**
 * (no documentation provided)
 */
- (void) setTypeId: (NSString *) newTypeId
{
  [newTypeId retain];
  [_typeId release];
  _typeId = newTypeId;
}

- (void) dealloc
{
  [self setName: nil];
  [self setSchedule: nil];
  [self setAlertEmail: nil];
  [self setProperties: nil];
  [self setId: nil];
  [self setTypeId: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0ScheduledServiceBaseResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0ScheduledServiceBaseResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0ScheduledServiceBaseResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0ScheduledServiceBaseResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0ScheduledServiceBaseResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0ScheduledServiceBaseResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0ScheduledServiceBaseResource *_nEXUS_REST_APINS0ScheduledServiceBaseResource = [[NEXUS_REST_APINS0ScheduledServiceBaseResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0ScheduledServiceBaseResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0ScheduledServiceBaseResource dealloc];
    _nEXUS_REST_APINS0ScheduledServiceBaseResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0ScheduledServiceBaseResource autorelease];
  return _nEXUS_REST_APINS0ScheduledServiceBaseResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0ScheduledServiceBaseResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0ScheduledServiceBaseResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "name", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setName: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "schedule", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}schedule of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}schedule of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setSchedule: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "alertEmail", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}alertEmail of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}alertEmail of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setAlertEmail: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "properties", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}properties...");
#endif
      //start wrapper element "{}properties"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "scheduled-task-property", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}scheduled-task-property of type {}scheduled-service-property-resource.");
#endif

    __child = [NEXUS_REST_APINS0ScheduledServicePropertyResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}scheduled-task-property of type {}scheduled-service-property-resource.");
#endif

    if ([self properties]) {
      [self setProperties: [[self properties] arrayByAddingObject: __child]];
    }
    else {
      [self setProperties: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}properties...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}properties"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setProperties: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "id", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setId: __child];
    return YES;
  } //end "if choice"


  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "enabled", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setEnabled: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "typeId", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}typeId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}typeId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setTypeId: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self name]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "name", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}name."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}name...");
#endif
    [[self name] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}name...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}name."];
    }
  }
  if ([self schedule]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "schedule", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}schedule."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}schedule...");
#endif
    [[self schedule] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}schedule...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}schedule."];
    }
  }
  if ([self alertEmail]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "alertEmail", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}alertEmail."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}alertEmail...");
#endif
    [[self alertEmail] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}alertEmail...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}alertEmail."];
    }
  }
  if ([self properties]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "properties", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}properties."];
    }
    __enumerator = [[self properties] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "scheduled-task-property", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}scheduled-task-property."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}scheduled-task-property...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}scheduled-task-property...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}scheduled-task-property."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}properties."];
    }
  }
  if ([self id]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "id", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}id."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}id...");
#endif
    [[self id] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}id...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}id."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "enabled", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}enabled."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}enabled...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_enabled);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}enabled...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}enabled."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}enabled."];
    }
  }
  if ([self typeId]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "typeId", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}typeId."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}typeId...");
#endif
    [[self typeId] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}typeId...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}typeId."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0ScheduledServiceBaseResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0ScheduledServiceBaseResource_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryRouteMemberRepository_M
#define DEF_NEXUS_REST_APINS0RepositoryRouteMemberRepository_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0RepositoryRouteMemberRepository

/**
 * (no documentation provided)
 */
- (NSString *) name
{
  return _name;
}

/**
 * (no documentation provided)
 */
- (void) setName: (NSString *) newName
{
  [newName retain];
  [_name release];
  _name = newName;
}

/**
 * (no documentation provided)
 */
- (NSString *) resourceURI
{
  return _resourceURI;
}

/**
 * (no documentation provided)
 */
- (void) setResourceURI: (NSString *) newResourceURI
{
  [newResourceURI retain];
  [_resourceURI release];
  _resourceURI = newResourceURI;
}

/**
 * (no documentation provided)
 */
- (NSString *) id
{
  return _id;
}

/**
 * (no documentation provided)
 */
- (void) setId: (NSString *) newId
{
  [newId retain];
  [_id release];
  _id = newId;
}

- (void) dealloc
{
  [self setName: nil];
  [self setResourceURI: nil];
  [self setId: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0RepositoryRouteMemberRepository */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryRouteMemberRepository (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0RepositoryRouteMemberRepository (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryRouteMemberRepository (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryRouteMemberRepository from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryRouteMemberRepository defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryRouteMemberRepository *_nEXUS_REST_APINS0RepositoryRouteMemberRepository = [[NEXUS_REST_APINS0RepositoryRouteMemberRepository alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryRouteMemberRepository initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryRouteMemberRepository dealloc];
    _nEXUS_REST_APINS0RepositoryRouteMemberRepository = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryRouteMemberRepository autorelease];
  return _nEXUS_REST_APINS0RepositoryRouteMemberRepository;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryRouteMemberRepository according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryRouteMemberRepository to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "name", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setName: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "resourceURI", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}resourceURI of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setResourceURI: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "id", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}id of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setId: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self name]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "name", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}name."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}name...");
#endif
    [[self name] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}name...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}name."];
    }
  }
  if ([self resourceURI]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "resourceURI", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}resourceURI."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}resourceURI...");
#endif
    [[self resourceURI] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}resourceURI...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}resourceURI."];
    }
  }
  if ([self id]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "id", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}id."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}id...");
#endif
    [[self id] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}id...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}id."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryRouteMemberRepository (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryRouteMemberRepository_M */
#ifndef DEF_NEXUS_REST_APINS0RemoteConnectionSettings_M
#define DEF_NEXUS_REST_APINS0RemoteConnectionSettings_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0RemoteConnectionSettings

/**
 * (no documentation provided)
 */
- (NSString *) userAgentString
{
  return _userAgentString;
}

/**
 * (no documentation provided)
 */
- (void) setUserAgentString: (NSString *) newUserAgentString
{
  [newUserAgentString retain];
  [_userAgentString release];
  _userAgentString = newUserAgentString;
}

/**
 * (no documentation provided)
 */
- (int) retrievalRetryCount
{
  return _retrievalRetryCount;
}

/**
 * (no documentation provided)
 */
- (void) setRetrievalRetryCount: (int) newRetrievalRetryCount
{
  _retrievalRetryCount = newRetrievalRetryCount;
}

/**
 * (no documentation provided)
 */
- (NSString *) queryString
{
  return _queryString;
}

/**
 * (no documentation provided)
 */
- (void) setQueryString: (NSString *) newQueryString
{
  [newQueryString retain];
  [_queryString release];
  _queryString = newQueryString;
}

/**
 * (no documentation provided)
 */
- (int) connectionTimeout
{
  return _connectionTimeout;
}

/**
 * (no documentation provided)
 */
- (void) setConnectionTimeout: (int) newConnectionTimeout
{
  _connectionTimeout = newConnectionTimeout;
}

- (void) dealloc
{
  [self setUserAgentString: nil];
  [self setQueryString: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0RemoteConnectionSettings */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RemoteConnectionSettings (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0RemoteConnectionSettings (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RemoteConnectionSettings (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RemoteConnectionSettings from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RemoteConnectionSettings defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RemoteConnectionSettings *_nEXUS_REST_APINS0RemoteConnectionSettings = [[NEXUS_REST_APINS0RemoteConnectionSettings alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RemoteConnectionSettings initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RemoteConnectionSettings dealloc];
    _nEXUS_REST_APINS0RemoteConnectionSettings = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RemoteConnectionSettings autorelease];
  return _nEXUS_REST_APINS0RemoteConnectionSettings;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RemoteConnectionSettings according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RemoteConnectionSettings to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "userAgentString", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}userAgentString of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}userAgentString of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setUserAgentString: __child];
    return YES;
  } //end "if choice"


  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "retrievalRetryCount", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadIntType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setRetrievalRetryCount: *((int*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "queryString", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}queryString of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}queryString of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setQueryString: __child];
    return YES;
  } //end "if choice"


  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "connectionTimeout", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadIntType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setConnectionTimeout: *((int*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self userAgentString]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "userAgentString", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}userAgentString."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}userAgentString...");
#endif
    [[self userAgentString] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}userAgentString...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}userAgentString."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "retrievalRetryCount", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}retrievalRetryCount."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}retrievalRetryCount...");
#endif
    status = xmlTextWriterWriteIntType(writer, &_retrievalRetryCount);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}retrievalRetryCount...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}retrievalRetryCount."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}retrievalRetryCount."];
    }
  }
  if ([self queryString]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "queryString", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}queryString."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}queryString...");
#endif
    [[self queryString] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}queryString...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}queryString."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "connectionTimeout", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}connectionTimeout."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}connectionTimeout...");
#endif
    status = xmlTextWriterWriteIntType(writer, &_connectionTimeout);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}connectionTimeout...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}connectionTimeout."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}connectionTimeout."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RemoteConnectionSettings (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RemoteConnectionSettings_M */
#ifndef DEF_NEXUS_REST_APINS0PrivilegeResource_M
#define DEF_NEXUS_REST_APINS0PrivilegeResource_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0PrivilegeResource

/**
 * (no documentation provided)
 */
- (NSString *) repositoryId
{
  return _repositoryId;
}

/**
 * (no documentation provided)
 */
- (void) setRepositoryId: (NSString *) newRepositoryId
{
  [newRepositoryId retain];
  [_repositoryId release];
  _repositoryId = newRepositoryId;
}

/**
 * (no documentation provided)
 */
- (NSString *) repositoryTargetId
{
  return _repositoryTargetId;
}

/**
 * (no documentation provided)
 */
- (void) setRepositoryTargetId: (NSString *) newRepositoryTargetId
{
  [newRepositoryTargetId retain];
  [_repositoryTargetId release];
  _repositoryTargetId = newRepositoryTargetId;
}

/**
 * (no documentation provided)
 */
- (NSString *) description
{
  return _description;
}

/**
 * (no documentation provided)
 */
- (void) setDescription: (NSString *) newDescription
{
  [newDescription retain];
  [_description release];
  _description = newDescription;
}

/**
 * (no documentation provided)
 */
- (NSString *) type
{
  return _type;
}

/**
 * (no documentation provided)
 */
- (void) setType: (NSString *) newType
{
  [newType retain];
  [_type release];
  _type = newType;
}

/**
 * (no documentation provided)
 */
- (NSString *) name
{
  return _name;
}

/**
 * (no documentation provided)
 */
- (void) setName: (NSString *) newName
{
  [newName retain];
  [_name release];
  _name = newName;
}

/**
 * (no documentation provided)
 */
- (NSArray *) method
{
  return _method;
}

/**
 * (no documentation provided)
 */
- (void) setMethod: (NSArray *) newMethod
{
  [newMethod retain];
  [_method release];
  _method = newMethod;
}

/**
 * (no documentation provided)
 */
- (NSString *) repositoryGroupId
{
  return _repositoryGroupId;
}

/**
 * (no documentation provided)
 */
- (void) setRepositoryGroupId: (NSString *) newRepositoryGroupId
{
  [newRepositoryGroupId retain];
  [_repositoryGroupId release];
  _repositoryGroupId = newRepositoryGroupId;
}

- (void) dealloc
{
  [self setRepositoryId: nil];
  [self setRepositoryTargetId: nil];
  [self setDescription: nil];
  [self setType: nil];
  [self setName: nil];
  [self setMethod: nil];
  [self setRepositoryGroupId: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0PrivilegeResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0PrivilegeResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0PrivilegeResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0PrivilegeResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0PrivilegeResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0PrivilegeResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0PrivilegeResource *_nEXUS_REST_APINS0PrivilegeResource = [[NEXUS_REST_APINS0PrivilegeResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0PrivilegeResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0PrivilegeResource dealloc];
    _nEXUS_REST_APINS0PrivilegeResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0PrivilegeResource autorelease];
  return _nEXUS_REST_APINS0PrivilegeResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0PrivilegeResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0PrivilegeResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "repositoryId", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}repositoryId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}repositoryId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setRepositoryId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "repositoryTargetId", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}repositoryTargetId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}repositoryTargetId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setRepositoryTargetId: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "description", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}description of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}description of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setDescription: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "type", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}type of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}type of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setType: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "name", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}name of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setName: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "methods", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}methods...");
#endif
      //start wrapper element "{}methods"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "method", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}method of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}method of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    if ([self method]) {
      [self setMethod: [[self method] arrayByAddingObject: __child]];
    }
    else {
      [self setMethod: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}methods...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}methods"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setMethod: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "repositoryGroupId", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}repositoryGroupId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}repositoryGroupId of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setRepositoryGroupId: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self repositoryId]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repositoryId", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}repositoryId."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}repositoryId...");
#endif
    [[self repositoryId] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}repositoryId...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}repositoryId."];
    }
  }
  if ([self repositoryTargetId]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repositoryTargetId", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}repositoryTargetId."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}repositoryTargetId...");
#endif
    [[self repositoryTargetId] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}repositoryTargetId...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}repositoryTargetId."];
    }
  }
  if ([self description]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "description", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}description."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}description...");
#endif
    [[self description] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}description...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}description."];
    }
  }
  if ([self type]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "type", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}type."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}type...");
#endif
    [[self type] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}type...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}type."];
    }
  }
  if ([self name]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "name", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}name."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}name...");
#endif
    [[self name] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}name...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}name."];
    }
  }
  if ([self method]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "methods", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}methods."];
    }
    __enumerator = [[self method] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "method", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}method."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}method...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}method...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}method."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}methods."];
    }
  }
  if ([self repositoryGroupId]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repositoryGroupId", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}repositoryGroupId."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}repositoryGroupId...");
#endif
    [[self repositoryGroupId] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}repositoryGroupId...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}repositoryGroupId."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0PrivilegeResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0PrivilegeResource_M */
#ifndef DEF_NEXUS_REST_APINS0ErrorReportingSettings_M
#define DEF_NEXUS_REST_APINS0ErrorReportingSettings_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0ErrorReportingSettings

/**
 * (no documentation provided)
 */
- (NSString *) jiraUsername
{
  return _jiraUsername;
}

/**
 * (no documentation provided)
 */
- (void) setJiraUsername: (NSString *) newJiraUsername
{
  [newJiraUsername retain];
  [_jiraUsername release];
  _jiraUsername = newJiraUsername;
}

/**
 * (no documentation provided)
 */
- (BOOL) reportErrorsAutomatically
{
  return _reportErrorsAutomatically;
}

/**
 * (no documentation provided)
 */
- (void) setReportErrorsAutomatically: (BOOL) newReportErrorsAutomatically
{
  _reportErrorsAutomatically = newReportErrorsAutomatically;
}

/**
 * (no documentation provided)
 */
- (BOOL) useGlobalProxy
{
  return _useGlobalProxy;
}

/**
 * (no documentation provided)
 */
- (void) setUseGlobalProxy: (BOOL) newUseGlobalProxy
{
  _useGlobalProxy = newUseGlobalProxy;
}

/**
 * (no documentation provided)
 */
- (NSString *) jiraPassword
{
  return _jiraPassword;
}

/**
 * (no documentation provided)
 */
- (void) setJiraPassword: (NSString *) newJiraPassword
{
  [newJiraPassword retain];
  [_jiraPassword release];
  _jiraPassword = newJiraPassword;
}

- (void) dealloc
{
  [self setJiraUsername: nil];
  [self setJiraPassword: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0ErrorReportingSettings */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0ErrorReportingSettings (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0ErrorReportingSettings (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0ErrorReportingSettings (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0ErrorReportingSettings from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0ErrorReportingSettings defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0ErrorReportingSettings *_nEXUS_REST_APINS0ErrorReportingSettings = [[NEXUS_REST_APINS0ErrorReportingSettings alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0ErrorReportingSettings initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0ErrorReportingSettings dealloc];
    _nEXUS_REST_APINS0ErrorReportingSettings = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0ErrorReportingSettings autorelease];
  return _nEXUS_REST_APINS0ErrorReportingSettings;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0ErrorReportingSettings according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0ErrorReportingSettings to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "jiraUsername", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}jiraUsername of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}jiraUsername of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setJiraUsername: __child];
    return YES;
  } //end "if choice"


  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "reportErrorsAutomatically", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setReportErrorsAutomatically: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "useGlobalProxy", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    _child_accessor = xmlTextReaderReadBooleanType(reader);
    if (_child_accessor == NULL) {
      //panic: unable to return the value for some reason.
      [self dealloc];
      [NSException raise: @"XMLReadError"
                   format: @"Error reading element value."];
    }
    [self setUseGlobalProxy: *((BOOL*) _child_accessor)];
    free(_child_accessor);
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "jiraPassword", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}jiraPassword of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}jiraPassword of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setJiraPassword: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self jiraUsername]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "jiraUsername", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}jiraUsername."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}jiraUsername...");
#endif
    [[self jiraUsername] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}jiraUsername...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}jiraUsername."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "reportErrorsAutomatically", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}reportErrorsAutomatically."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}reportErrorsAutomatically...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_reportErrorsAutomatically);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}reportErrorsAutomatically...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}reportErrorsAutomatically."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}reportErrorsAutomatically."];
    }
  }
  if (YES) { //always write the primitive element...
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "useGlobalProxy", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}useGlobalProxy."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}useGlobalProxy...");
#endif
    status = xmlTextWriterWriteBooleanType(writer, &_useGlobalProxy);
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}useGlobalProxy...");
#endif
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing child element {}useGlobalProxy."];
    }

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}useGlobalProxy."];
    }
  }
  if ([self jiraPassword]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "jiraPassword", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}jiraPassword."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}jiraPassword...");
#endif
    [[self jiraPassword] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}jiraPassword...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}jiraPassword."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0ErrorReportingSettings (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0ErrorReportingSettings_M */
#ifndef DEF_NEXUS_REST_APINS0ErrorReportRequest_M
#define DEF_NEXUS_REST_APINS0ErrorReportRequest_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0ErrorReportRequest

/**
 * (no documentation provided)
 */
- (NEXUS_REST_APINS0ErrorReportRequestDTO *) data
{
  return _data;
}

/**
 * (no documentation provided)
 */
- (void) setData: (NEXUS_REST_APINS0ErrorReportRequestDTO *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0ErrorReportRequest *_nEXUS_REST_APINS0ErrorReportRequest;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0ErrorReportRequest = (NEXUS_REST_APINS0ErrorReportRequest *) [NEXUS_REST_APINS0ErrorReportRequest readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0ErrorReportRequest;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0ErrorReportRequest */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0ErrorReportRequest (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0ErrorReportRequest (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0ErrorReportRequest (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0ErrorReportRequest from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0ErrorReportRequest defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0ErrorReportRequest *_nEXUS_REST_APINS0ErrorReportRequest = [[NEXUS_REST_APINS0ErrorReportRequest alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0ErrorReportRequest initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0ErrorReportRequest dealloc];
    _nEXUS_REST_APINS0ErrorReportRequest = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0ErrorReportRequest autorelease];
  return _nEXUS_REST_APINS0ErrorReportRequest;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0ErrorReportRequest according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0ErrorReportRequest to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0ErrorReportRequest from an XML reader. The element to be read is
 * "error-report-request".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0ErrorReportRequest.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0ErrorReportRequest *_errorReportRequest = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element error-report-request."];
    }
  }

  if (xmlStrcmp(BAD_CAST "error-report-request", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}error-report-request.");
#endif
    _errorReportRequest = (NEXUS_REST_APINS0ErrorReportRequest *)[NEXUS_REST_APINS0ErrorReportRequest readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}error-report-request.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0ErrorReportRequest. Expected element error-report-request. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0ErrorReportRequest. Expected element error-report-request. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _errorReportRequest;
}

/**
 * Writes this NEXUS_REST_APINS0ErrorReportRequest to XML under element name "error-report-request".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _errorReportRequest The ErrorReportRequest to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0ErrorReportRequest to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "error-report-request", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}error-report-request. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}errorReportRequest for root element {}error-report-request...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}errorReportRequest for root element {}error-report-request...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}error-report-request. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}error-report-request-dto.");
#endif
    __child = [NEXUS_REST_APINS0ErrorReportRequestDTO readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}error-report-request-dto.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0ErrorReportRequest (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0ErrorReportRequest_M */
#ifndef DEF_NEXUS_REST_APINS0AuthenticationSettings_M
#define DEF_NEXUS_REST_APINS0AuthenticationSettings_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0AuthenticationSettings

/**
 * (no documentation provided)
 */
- (NSString *) password
{
  return _password;
}

/**
 * (no documentation provided)
 */
- (void) setPassword: (NSString *) newPassword
{
  [newPassword retain];
  [_password release];
  _password = newPassword;
}

/**
 * (no documentation provided)
 */
- (NSString *) username
{
  return _username;
}

/**
 * (no documentation provided)
 */
- (void) setUsername: (NSString *) newUsername
{
  [newUsername retain];
  [_username release];
  _username = newUsername;
}

/**
 * (no documentation provided)
 */
- (NSString *) ntlmDomain
{
  return _ntlmDomain;
}

/**
 * (no documentation provided)
 */
- (void) setNtlmDomain: (NSString *) newNtlmDomain
{
  [newNtlmDomain retain];
  [_ntlmDomain release];
  _ntlmDomain = newNtlmDomain;
}

/**
 * (no documentation provided)
 */
- (NSString *) ntlmHost
{
  return _ntlmHost;
}

/**
 * (no documentation provided)
 */
- (void) setNtlmHost: (NSString *) newNtlmHost
{
  [newNtlmHost retain];
  [_ntlmHost release];
  _ntlmHost = newNtlmHost;
}

- (void) dealloc
{
  [self setPassword: nil];
  [self setUsername: nil];
  [self setNtlmDomain: nil];
  [self setNtlmHost: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0AuthenticationSettings */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0AuthenticationSettings (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0AuthenticationSettings (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0AuthenticationSettings (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0AuthenticationSettings from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0AuthenticationSettings defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0AuthenticationSettings *_nEXUS_REST_APINS0AuthenticationSettings = [[NEXUS_REST_APINS0AuthenticationSettings alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0AuthenticationSettings initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0AuthenticationSettings dealloc];
    _nEXUS_REST_APINS0AuthenticationSettings = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0AuthenticationSettings autorelease];
  return _nEXUS_REST_APINS0AuthenticationSettings;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0AuthenticationSettings according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0AuthenticationSettings to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "password", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}password of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}password of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setPassword: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "username", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}username of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}username of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setUsername: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "ntlmDomain", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}ntlmDomain of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}ntlmDomain of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setNtlmDomain: __child];
    return YES;
  } //end "if choice"

  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "ntlmHost", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}ntlmHost of type {http://www.w3.org/2001/XMLSchema}string.");
#endif
    __child = [NSString readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}ntlmHost of type {http://www.w3.org/2001/XMLSchema}string.");
#endif

    [self setNtlmHost: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self password]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "password", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}password."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}password...");
#endif
    [[self password] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}password...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}password."];
    }
  }
  if ([self username]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "username", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}username."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}username...");
#endif
    [[self username] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}username...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}username."];
    }
  }
  if ([self ntlmDomain]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "ntlmDomain", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}ntlmDomain."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}ntlmDomain...");
#endif
    [[self ntlmDomain] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}ntlmDomain...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}ntlmDomain."];
    }
  }
  if ([self ntlmHost]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "ntlmHost", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}ntlmHost."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}ntlmHost...");
#endif
    [[self ntlmHost] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}ntlmHost...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}ntlmHost."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0AuthenticationSettings (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0AuthenticationSettings_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryStatusResourceResponse_M
#define DEF_NEXUS_REST_APINS0RepositoryStatusResourceResponse_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0RepositoryStatusResourceResponse

/**
 * (no documentation provided)
 */
- (NEXUS_REST_APINS0RepositoryStatusResource *) data
{
  return _data;
}

/**
 * (no documentation provided)
 */
- (void) setData: (NEXUS_REST_APINS0RepositoryStatusResource *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0RepositoryStatusResourceResponse *_nEXUS_REST_APINS0RepositoryStatusResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0RepositoryStatusResourceResponse = (NEXUS_REST_APINS0RepositoryStatusResourceResponse *) [NEXUS_REST_APINS0RepositoryStatusResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0RepositoryStatusResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0RepositoryStatusResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryStatusResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0RepositoryStatusResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryStatusResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryStatusResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryStatusResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryStatusResourceResponse *_nEXUS_REST_APINS0RepositoryStatusResourceResponse = [[NEXUS_REST_APINS0RepositoryStatusResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryStatusResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryStatusResourceResponse dealloc];
    _nEXUS_REST_APINS0RepositoryStatusResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryStatusResourceResponse autorelease];
  return _nEXUS_REST_APINS0RepositoryStatusResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryStatusResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryStatusResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0RepositoryStatusResourceResponse from an XML reader. The element to be read is
 * "repository-status".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0RepositoryStatusResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0RepositoryStatusResourceResponse *_repositoryStatusResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element repository-status."];
    }
  }

  if (xmlStrcmp(BAD_CAST "repository-status", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}repository-status.");
#endif
    _repositoryStatusResourceResponse = (NEXUS_REST_APINS0RepositoryStatusResourceResponse *)[NEXUS_REST_APINS0RepositoryStatusResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}repository-status.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0RepositoryStatusResourceResponse. Expected element repository-status. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0RepositoryStatusResourceResponse. Expected element repository-status. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _repositoryStatusResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0RepositoryStatusResourceResponse to XML under element name "repository-status".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _repositoryStatusResourceResponse The RepositoryStatusResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0RepositoryStatusResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repository-status", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}repository-status. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}repositoryStatusResourceResponse for root element {}repository-status...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}repositoryStatusResourceResponse for root element {}repository-status...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}repository-status. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}repository-status.");
#endif
    __child = [NEXUS_REST_APINS0RepositoryStatusResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}repository-status.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryStatusResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryStatusResourceResponse_M */
#ifndef DEF_NEXUS_REST_APINS0SmtpSettingsResourceRequest_M
#define DEF_NEXUS_REST_APINS0SmtpSettingsResourceRequest_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0SmtpSettingsResourceRequest

/**
 * (no documentation provided)
 */
- (NEXUS_REST_APINS0SmtpSettingsResource *) data
{
  return _data;
}

/**
 * (no documentation provided)
 */
- (void) setData: (NEXUS_REST_APINS0SmtpSettingsResource *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0SmtpSettingsResourceRequest *_nEXUS_REST_APINS0SmtpSettingsResourceRequest;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0SmtpSettingsResourceRequest = (NEXUS_REST_APINS0SmtpSettingsResourceRequest *) [NEXUS_REST_APINS0SmtpSettingsResourceRequest readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0SmtpSettingsResourceRequest;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0SmtpSettingsResourceRequest */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0SmtpSettingsResourceRequest (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0SmtpSettingsResourceRequest (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0SmtpSettingsResourceRequest (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0SmtpSettingsResourceRequest from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0SmtpSettingsResourceRequest defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0SmtpSettingsResourceRequest *_nEXUS_REST_APINS0SmtpSettingsResourceRequest = [[NEXUS_REST_APINS0SmtpSettingsResourceRequest alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0SmtpSettingsResourceRequest initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0SmtpSettingsResourceRequest dealloc];
    _nEXUS_REST_APINS0SmtpSettingsResourceRequest = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0SmtpSettingsResourceRequest autorelease];
  return _nEXUS_REST_APINS0SmtpSettingsResourceRequest;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0SmtpSettingsResourceRequest according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0SmtpSettingsResourceRequest to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0SmtpSettingsResourceRequest from an XML reader. The element to be read is
 * "smtp-settings-request".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0SmtpSettingsResourceRequest.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0SmtpSettingsResourceRequest *_smtpSettingsResourceRequest = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element smtp-settings-request."];
    }
  }

  if (xmlStrcmp(BAD_CAST "smtp-settings-request", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}smtp-settings-request.");
#endif
    _smtpSettingsResourceRequest = (NEXUS_REST_APINS0SmtpSettingsResourceRequest *)[NEXUS_REST_APINS0SmtpSettingsResourceRequest readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}smtp-settings-request.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0SmtpSettingsResourceRequest. Expected element smtp-settings-request. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0SmtpSettingsResourceRequest. Expected element smtp-settings-request. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _smtpSettingsResourceRequest;
}

/**
 * Writes this NEXUS_REST_APINS0SmtpSettingsResourceRequest to XML under element name "smtp-settings-request".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _smtpSettingsResourceRequest The SmtpSettingsResourceRequest to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0SmtpSettingsResourceRequest to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "smtp-settings-request", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}smtp-settings-request. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}smtpSettingsResourceRequest for root element {}smtp-settings-request...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}smtpSettingsResourceRequest for root element {}smtp-settings-request...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}smtp-settings-request. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}smtp-settings-resource.");
#endif
    __child = [NEXUS_REST_APINS0SmtpSettingsResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}smtp-settings-resource.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0SmtpSettingsResourceRequest (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0SmtpSettingsResourceRequest_M */
#ifndef DEF_NEXUS_REST_APINS0ScheduledServiceResourceResponse_M
#define DEF_NEXUS_REST_APINS0ScheduledServiceResourceResponse_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0ScheduledServiceResourceResponse

/**
 * (no documentation provided)
 */
- (NEXUS_REST_APINS0ScheduledServiceBaseResource *) data
{
  return _data;
}

/**
 * (no documentation provided)
 */
- (void) setData: (NEXUS_REST_APINS0ScheduledServiceBaseResource *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0ScheduledServiceResourceResponse *_nEXUS_REST_APINS0ScheduledServiceResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0ScheduledServiceResourceResponse = (NEXUS_REST_APINS0ScheduledServiceResourceResponse *) [NEXUS_REST_APINS0ScheduledServiceResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0ScheduledServiceResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0ScheduledServiceResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0ScheduledServiceResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0ScheduledServiceResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0ScheduledServiceResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0ScheduledServiceResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0ScheduledServiceResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0ScheduledServiceResourceResponse *_nEXUS_REST_APINS0ScheduledServiceResourceResponse = [[NEXUS_REST_APINS0ScheduledServiceResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0ScheduledServiceResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0ScheduledServiceResourceResponse dealloc];
    _nEXUS_REST_APINS0ScheduledServiceResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0ScheduledServiceResourceResponse autorelease];
  return _nEXUS_REST_APINS0ScheduledServiceResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0ScheduledServiceResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0ScheduledServiceResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0ScheduledServiceResourceResponse from an XML reader. The element to be read is
 * "scheduled-task".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0ScheduledServiceResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0ScheduledServiceResourceResponse *_scheduledServiceResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element scheduled-task."];
    }
  }

  if (xmlStrcmp(BAD_CAST "scheduled-task", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}scheduled-task.");
#endif
    _scheduledServiceResourceResponse = (NEXUS_REST_APINS0ScheduledServiceResourceResponse *)[NEXUS_REST_APINS0ScheduledServiceResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}scheduled-task.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0ScheduledServiceResourceResponse. Expected element scheduled-task. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0ScheduledServiceResourceResponse. Expected element scheduled-task. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _scheduledServiceResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0ScheduledServiceResourceResponse to XML under element name "scheduled-task".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _scheduledServiceResourceResponse The ScheduledServiceResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0ScheduledServiceResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "scheduled-task", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}scheduled-task. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}scheduledServiceResourceResponse for root element {}scheduled-task...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}scheduledServiceResourceResponse for root element {}scheduled-task...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}scheduled-task. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}scheduled-service-base-resource.");
#endif
    __child = [NEXUS_REST_APINS0ScheduledServiceBaseResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}scheduled-service-base-resource.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0ScheduledServiceResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0ScheduledServiceResourceResponse_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryTargetResourceResponse_M
#define DEF_NEXUS_REST_APINS0RepositoryTargetResourceResponse_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0RepositoryTargetResourceResponse

/**
 * (no documentation provided)
 */
- (NEXUS_REST_APINS0RepositoryTargetResource *) data
{
  return _data;
}

/**
 * (no documentation provided)
 */
- (void) setData: (NEXUS_REST_APINS0RepositoryTargetResource *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0RepositoryTargetResourceResponse *_nEXUS_REST_APINS0RepositoryTargetResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0RepositoryTargetResourceResponse = (NEXUS_REST_APINS0RepositoryTargetResourceResponse *) [NEXUS_REST_APINS0RepositoryTargetResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0RepositoryTargetResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0RepositoryTargetResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryTargetResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0RepositoryTargetResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryTargetResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryTargetResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryTargetResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryTargetResourceResponse *_nEXUS_REST_APINS0RepositoryTargetResourceResponse = [[NEXUS_REST_APINS0RepositoryTargetResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryTargetResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryTargetResourceResponse dealloc];
    _nEXUS_REST_APINS0RepositoryTargetResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryTargetResourceResponse autorelease];
  return _nEXUS_REST_APINS0RepositoryTargetResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryTargetResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryTargetResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0RepositoryTargetResourceResponse from an XML reader. The element to be read is
 * "repo-target".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0RepositoryTargetResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0RepositoryTargetResourceResponse *_repositoryTargetResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element repo-target."];
    }
  }

  if (xmlStrcmp(BAD_CAST "repo-target", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}repo-target.");
#endif
    _repositoryTargetResourceResponse = (NEXUS_REST_APINS0RepositoryTargetResourceResponse *)[NEXUS_REST_APINS0RepositoryTargetResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}repo-target.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0RepositoryTargetResourceResponse. Expected element repo-target. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0RepositoryTargetResourceResponse. Expected element repo-target. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _repositoryTargetResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0RepositoryTargetResourceResponse to XML under element name "repo-target".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _repositoryTargetResourceResponse The RepositoryTargetResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0RepositoryTargetResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repo-target", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}repo-target. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}repositoryTargetResourceResponse for root element {}repo-target...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}repositoryTargetResourceResponse for root element {}repo-target...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}repo-target. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}repository-target-resource.");
#endif
    __child = [NEXUS_REST_APINS0RepositoryTargetResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}repository-target-resource.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryTargetResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryTargetResourceResponse_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryRouteResourceResponse_M
#define DEF_NEXUS_REST_APINS0RepositoryRouteResourceResponse_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0RepositoryRouteResourceResponse

/**
 * (no documentation provided)
 */
- (NEXUS_REST_APINS0RepositoryRouteResource *) data
{
  return _data;
}

/**
 * (no documentation provided)
 */
- (void) setData: (NEXUS_REST_APINS0RepositoryRouteResource *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0RepositoryRouteResourceResponse *_nEXUS_REST_APINS0RepositoryRouteResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0RepositoryRouteResourceResponse = (NEXUS_REST_APINS0RepositoryRouteResourceResponse *) [NEXUS_REST_APINS0RepositoryRouteResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0RepositoryRouteResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0RepositoryRouteResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryRouteResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0RepositoryRouteResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryRouteResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryRouteResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryRouteResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryRouteResourceResponse *_nEXUS_REST_APINS0RepositoryRouteResourceResponse = [[NEXUS_REST_APINS0RepositoryRouteResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryRouteResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryRouteResourceResponse dealloc];
    _nEXUS_REST_APINS0RepositoryRouteResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryRouteResourceResponse autorelease];
  return _nEXUS_REST_APINS0RepositoryRouteResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryRouteResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryRouteResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0RepositoryRouteResourceResponse from an XML reader. The element to be read is
 * "repo-route".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0RepositoryRouteResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0RepositoryRouteResourceResponse *_repositoryRouteResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element repo-route."];
    }
  }

  if (xmlStrcmp(BAD_CAST "repo-route", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}repo-route.");
#endif
    _repositoryRouteResourceResponse = (NEXUS_REST_APINS0RepositoryRouteResourceResponse *)[NEXUS_REST_APINS0RepositoryRouteResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}repo-route.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0RepositoryRouteResourceResponse. Expected element repo-route. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0RepositoryRouteResourceResponse. Expected element repo-route. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _repositoryRouteResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0RepositoryRouteResourceResponse to XML under element name "repo-route".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _repositoryRouteResourceResponse The RepositoryRouteResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0RepositoryRouteResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repo-route", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}repo-route. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}repositoryRouteResourceResponse for root element {}repo-route...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}repositoryRouteResourceResponse for root element {}repo-route...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}repo-route. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}repository-route-resource.");
#endif
    __child = [NEXUS_REST_APINS0RepositoryRouteResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}repository-route-resource.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryRouteResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryRouteResourceResponse_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryGroupResource_M
#define DEF_NEXUS_REST_APINS0RepositoryGroupResource_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0RepositoryGroupResource

/**
 * (no documentation provided)
 */
- (NSArray *) repositories
{
  return _repositories;
}

/**
 * (no documentation provided)
 */
- (void) setRepositories: (NSArray *) newRepositories
{
  [newRepositories retain];
  [_repositories release];
  _repositories = newRepositories;
}

- (void) dealloc
{
  [self setRepositories: nil];
  [super dealloc];
}
@end /* implementation NEXUS_REST_APINS0RepositoryGroupResource */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryGroupResource (JAXB) <JAXBReading, JAXBWriting, JAXBType>

@end /*interface NEXUS_REST_APINS0RepositoryGroupResource (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryGroupResource (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryGroupResource from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryGroupResource defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryGroupResource *_nEXUS_REST_APINS0RepositoryGroupResource = [[NEXUS_REST_APINS0RepositoryGroupResource alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryGroupResource initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryGroupResource dealloc];
    _nEXUS_REST_APINS0RepositoryGroupResource = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryGroupResource autorelease];
  return _nEXUS_REST_APINS0RepositoryGroupResource;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryGroupResource according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryGroupResource to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "repositories", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}repositories...");
#endif
      //start wrapper element "{}repositories"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "repo-group-member", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}repo-group-member of type {}repository-group-member-repository.");
#endif

    __child = [NEXUS_REST_APINS0RepositoryGroupMemberRepository readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}repo-group-member of type {}repository-group-member-repository.");
#endif

    if ([self repositories]) {
      [self setRepositories: [[self repositories] arrayByAddingObject: __child]];
    }
    else {
      [self setRepositories: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}repositories...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}repositories"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setRepositories: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self repositories]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repositories", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}repositories."];
    }
    __enumerator = [[self repositories] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repo-group-member", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}repo-group-member."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}repo-group-member...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}repo-group-member...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}repo-group-member."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}repositories."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryGroupResource (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryGroupResource_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryGroupResourceResponse_M
#define DEF_NEXUS_REST_APINS0RepositoryGroupResourceResponse_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0RepositoryGroupResourceResponse

/**
 * (no documentation provided)
 */
- (NEXUS_REST_APINS0RepositoryGroupResource *) data
{
  return _data;
}

/**
 * (no documentation provided)
 */
- (void) setData: (NEXUS_REST_APINS0RepositoryGroupResource *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0RepositoryGroupResourceResponse *_nEXUS_REST_APINS0RepositoryGroupResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0RepositoryGroupResourceResponse = (NEXUS_REST_APINS0RepositoryGroupResourceResponse *) [NEXUS_REST_APINS0RepositoryGroupResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0RepositoryGroupResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0RepositoryGroupResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryGroupResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0RepositoryGroupResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryGroupResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryGroupResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryGroupResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryGroupResourceResponse *_nEXUS_REST_APINS0RepositoryGroupResourceResponse = [[NEXUS_REST_APINS0RepositoryGroupResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryGroupResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryGroupResourceResponse dealloc];
    _nEXUS_REST_APINS0RepositoryGroupResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryGroupResourceResponse autorelease];
  return _nEXUS_REST_APINS0RepositoryGroupResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryGroupResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryGroupResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0RepositoryGroupResourceResponse from an XML reader. The element to be read is
 * "repo-group".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0RepositoryGroupResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0RepositoryGroupResourceResponse *_repositoryGroupResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element repo-group."];
    }
  }

  if (xmlStrcmp(BAD_CAST "repo-group", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}repo-group.");
#endif
    _repositoryGroupResourceResponse = (NEXUS_REST_APINS0RepositoryGroupResourceResponse *)[NEXUS_REST_APINS0RepositoryGroupResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}repo-group.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0RepositoryGroupResourceResponse. Expected element repo-group. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0RepositoryGroupResourceResponse. Expected element repo-group. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _repositoryGroupResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0RepositoryGroupResourceResponse to XML under element name "repo-group".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _repositoryGroupResourceResponse The RepositoryGroupResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0RepositoryGroupResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repo-group", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}repo-group. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}repositoryGroupResourceResponse for root element {}repo-group...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}repositoryGroupResourceResponse for root element {}repo-group...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}repo-group. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}repository-group-resource.");
#endif
    __child = [NEXUS_REST_APINS0RepositoryGroupResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}repository-group-resource.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryGroupResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryGroupResourceResponse_M */
#ifndef DEF_NEXUS_REST_APINS0RepositoryResourceResponse_M
#define DEF_NEXUS_REST_APINS0RepositoryResourceResponse_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0RepositoryResourceResponse

/**
 * (no documentation provided)
 */
- (NEXUS_REST_APINS0RepositoryBaseResource *) data
{
  return _data;
}

/**
 * (no documentation provided)
 */
- (void) setData: (NEXUS_REST_APINS0RepositoryBaseResource *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0RepositoryResourceResponse *_nEXUS_REST_APINS0RepositoryResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0RepositoryResourceResponse = (NEXUS_REST_APINS0RepositoryResourceResponse *) [NEXUS_REST_APINS0RepositoryResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0RepositoryResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0RepositoryResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0RepositoryResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0RepositoryResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0RepositoryResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0RepositoryResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0RepositoryResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0RepositoryResourceResponse *_nEXUS_REST_APINS0RepositoryResourceResponse = [[NEXUS_REST_APINS0RepositoryResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0RepositoryResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0RepositoryResourceResponse dealloc];
    _nEXUS_REST_APINS0RepositoryResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0RepositoryResourceResponse autorelease];
  return _nEXUS_REST_APINS0RepositoryResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0RepositoryResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0RepositoryResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0RepositoryResourceResponse from an XML reader. The element to be read is
 * "repository".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0RepositoryResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0RepositoryResourceResponse *_repositoryResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element repository."];
    }
  }

  if (xmlStrcmp(BAD_CAST "repository", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}repository.");
#endif
    _repositoryResourceResponse = (NEXUS_REST_APINS0RepositoryResourceResponse *)[NEXUS_REST_APINS0RepositoryResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}repository.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0RepositoryResourceResponse. Expected element repository. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0RepositoryResourceResponse. Expected element repository. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _repositoryResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0RepositoryResourceResponse to XML under element name "repository".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _repositoryResourceResponse The RepositoryResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0RepositoryResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "repository", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}repository. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}repositoryResourceResponse for root element {}repository...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}repositoryResourceResponse for root element {}repository...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}repository. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}base-repository.");
#endif
    __child = [NEXUS_REST_APINS0RepositoryBaseResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}base-repository.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0RepositoryResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0RepositoryResourceResponse_M */
#ifndef DEF_NEXUS_REST_APINS0MirrorResourceListRequest_M
#define DEF_NEXUS_REST_APINS0MirrorResourceListRequest_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0MirrorResourceListRequest

/**
 * (no documentation provided)
 */
- (NSArray *) data
{
  return _data;
}

/**
 * (no documentation provided)
 */
- (void) setData: (NSArray *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0MirrorResourceListRequest *_nEXUS_REST_APINS0MirrorResourceListRequest;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0MirrorResourceListRequest = (NEXUS_REST_APINS0MirrorResourceListRequest *) [NEXUS_REST_APINS0MirrorResourceListRequest readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0MirrorResourceListRequest;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0MirrorResourceListRequest */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0MirrorResourceListRequest (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0MirrorResourceListRequest (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0MirrorResourceListRequest (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0MirrorResourceListRequest from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0MirrorResourceListRequest defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0MirrorResourceListRequest *_nEXUS_REST_APINS0MirrorResourceListRequest = [[NEXUS_REST_APINS0MirrorResourceListRequest alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0MirrorResourceListRequest initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0MirrorResourceListRequest dealloc];
    _nEXUS_REST_APINS0MirrorResourceListRequest = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0MirrorResourceListRequest autorelease];
  return _nEXUS_REST_APINS0MirrorResourceListRequest;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0MirrorResourceListRequest according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0MirrorResourceListRequest to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0MirrorResourceListRequest from an XML reader. The element to be read is
 * "mirror-list-request".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0MirrorResourceListRequest.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0MirrorResourceListRequest *_mirrorResourceListRequest = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element mirror-list-request."];
    }
  }

  if (xmlStrcmp(BAD_CAST "mirror-list-request", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}mirror-list-request.");
#endif
    _mirrorResourceListRequest = (NEXUS_REST_APINS0MirrorResourceListRequest *)[NEXUS_REST_APINS0MirrorResourceListRequest readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}mirror-list-request.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0MirrorResourceListRequest. Expected element mirror-list-request. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0MirrorResourceListRequest. Expected element mirror-list-request. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _mirrorResourceListRequest;
}

/**
 * Writes this NEXUS_REST_APINS0MirrorResourceListRequest to XML under element name "mirror-list-request".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _mirrorResourceListRequest The MirrorResourceListRequest to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0MirrorResourceListRequest to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "mirror-list-request", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}mirror-list-request. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}mirrorResourceListRequest for root element {}mirror-list-request...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}mirrorResourceListRequest for root element {}mirror-list-request...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}mirror-list-request. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

    if (xmlTextReaderIsEmptyElement(reader) == 0) {
#if DEBUG_ENUNCIATE > 1
      NSLog(@"Unwrapping wrapper element {}data...");
#endif
      //start wrapper element "{}data"
      depth = xmlTextReaderDepth(reader);
      status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      while (xmlTextReaderDepth(reader) > depth) {
        if (status < 1) {
          //panic: XML read error.
          [self dealloc];
          [NSException raise: @"XMLReadError"
                       format: @"Failure to advance to next wrapped child element."];
        }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "mirrorResource", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}mirrorResource of type {}mirror-resource.");
#endif

    __child = [NEXUS_REST_APINS0MirrorResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}mirrorResource of type {}mirror-resource.");
#endif

    if ([self data]) {
      [self setData: [[self data] arrayByAddingObject: __child]];
    }
    else {
      [self setData: [NSArray arrayWithObject: __child]];
    }
    continue; //continue "while in wrapper element" loop
  } //end "if choice"

        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
#if DEBUG_ENUNCIATE > 1
        NSLog(@"successfully unwrapped wrapper element {}data...");
#endif
      } // end "while in wrapper element" loop

      if (status < 1) {
        //panic: XML read error.
        [self dealloc];
        [NSException raise: @"XMLReadError"
                     format: @"Failure to advance to end wrapper element."];
      }
      else {
        //end wrapper element "{}data"
        status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
      }
    } //end "if empty element" clause
    else {
      __child = [NSArray array];
      [self setData: (NSArray*) __child];
    }

    return YES;
  } // end "if wrapper element" clause

  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start wrapper element {}data."];
    }
    __enumerator = [[self data] objectEnumerator];

    while ( (__item = [__enumerator nextObject]) ) {
      status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "mirrorResource", NULL);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing start child element {}mirrorResource."];
      }

#if DEBUG_ENUNCIATE > 1
      NSLog(@"writing element {}mirrorResource...");
#endif
      [__item writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
      NSLog(@"successfully wrote element {}mirrorResource...");
#endif

      status = xmlTextWriterEndElement(writer);
      if (status < 0) {
        [NSException raise: @"XMLWriteError"
                     format: @"Error writing end child element {}mirrorResource."];
      }
    } //end item iterator.

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end wrapper element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0MirrorResourceListRequest (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0MirrorResourceListRequest_M */
#ifndef DEF_NEXUS_REST_APINS0LogConfigResourceResponse_M
#define DEF_NEXUS_REST_APINS0LogConfigResourceResponse_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0LogConfigResourceResponse

/**
 * (no documentation provided)
 */
- (NEXUS_REST_APINS0LogConfigResource *) data
{
  return _data;
}

/**
 * (no documentation provided)
 */
- (void) setData: (NEXUS_REST_APINS0LogConfigResource *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0LogConfigResourceResponse *_nEXUS_REST_APINS0LogConfigResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0LogConfigResourceResponse = (NEXUS_REST_APINS0LogConfigResourceResponse *) [NEXUS_REST_APINS0LogConfigResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0LogConfigResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0LogConfigResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0LogConfigResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0LogConfigResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0LogConfigResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0LogConfigResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0LogConfigResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0LogConfigResourceResponse *_nEXUS_REST_APINS0LogConfigResourceResponse = [[NEXUS_REST_APINS0LogConfigResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0LogConfigResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0LogConfigResourceResponse dealloc];
    _nEXUS_REST_APINS0LogConfigResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0LogConfigResourceResponse autorelease];
  return _nEXUS_REST_APINS0LogConfigResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0LogConfigResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0LogConfigResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0LogConfigResourceResponse from an XML reader. The element to be read is
 * "log-config".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0LogConfigResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0LogConfigResourceResponse *_logConfigResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element log-config."];
    }
  }

  if (xmlStrcmp(BAD_CAST "log-config", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}log-config.");
#endif
    _logConfigResourceResponse = (NEXUS_REST_APINS0LogConfigResourceResponse *)[NEXUS_REST_APINS0LogConfigResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}log-config.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0LogConfigResourceResponse. Expected element log-config. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0LogConfigResourceResponse. Expected element log-config. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _logConfigResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0LogConfigResourceResponse to XML under element name "log-config".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _logConfigResourceResponse The LogConfigResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0LogConfigResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "log-config", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}log-config. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}logConfigResourceResponse for root element {}log-config...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}logConfigResourceResponse for root element {}log-config...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}log-config. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}log-config-resource.");
#endif
    __child = [NEXUS_REST_APINS0LogConfigResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}log-config-resource.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0LogConfigResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0LogConfigResourceResponse_M */
#ifndef DEF_NEXUS_REST_APINS0GlobalConfigurationResourceResponse_M
#define DEF_NEXUS_REST_APINS0GlobalConfigurationResourceResponse_M

/**
 * (no documentation provided)
 */
@implementation NEXUS_REST_APINS0GlobalConfigurationResourceResponse

/**
 * (no documentation provided)
 */
- (NEXUS_REST_APINS0GlobalConfigurationResource *) data
{
  return _data;
}

/**
 * (no documentation provided)
 */
- (void) setData: (NEXUS_REST_APINS0GlobalConfigurationResource *) newData
{
  [newData retain];
  [_data release];
  _data = newData;
}

- (void) dealloc
{
  [self setData: nil];
  [super dealloc];
}

//documentation inherited.
+ (id<EnunciateXML>) readFromXML: (NSData *) xml
{
  NEXUS_REST_APINS0GlobalConfigurationResourceResponse *_nEXUS_REST_APINS0GlobalConfigurationResourceResponse;
  xmlTextReaderPtr reader = xmlReaderForMemory([xml bytes], [xml length], NULL, NULL, 0);
  if (reader == NULL) {
    [NSException raise: @"XMLReadError"
                 format: @"Error instantiating an XML reader."];
    return nil;
  }

  _nEXUS_REST_APINS0GlobalConfigurationResourceResponse = (NEXUS_REST_APINS0GlobalConfigurationResourceResponse *) [NEXUS_REST_APINS0GlobalConfigurationResourceResponse readXMLElement: reader];
  xmlFreeTextReader(reader); //free the reader
  return _nEXUS_REST_APINS0GlobalConfigurationResourceResponse;
}

//documentation inherited.
- (NSData *) writeToXML
{
  xmlBufferPtr buf;
  xmlTextWriterPtr writer;
  int rc;
  NSData *data;

  buf = xmlBufferCreate();
  if (buf == NULL) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML buffer."];
    return nil;
  }

  writer = xmlNewTextWriterMemory(buf, 0);
  if (writer == NULL) {
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error creating an XML writer."];
    return nil;
  }

  rc = xmlTextWriterStartDocument(writer, NULL, "utf-8", NULL);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML start document."];
    return nil;
  }

  NS_DURING
  {
    [self writeXMLElement: writer];
  }
  NS_HANDLER
  {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [localException raise];
  }
  NS_ENDHANDLER

  rc = xmlTextWriterEndDocument(writer);
  if (rc < 0) {
    xmlFreeTextWriter(writer);
    xmlBufferFree(buf);
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing XML end document."];
    return nil;
  }

  xmlFreeTextWriter(writer);
  data = [NSData dataWithBytes: buf->content length: buf->use];
  xmlBufferFree(buf);
  return data;
}
@end /* implementation NEXUS_REST_APINS0GlobalConfigurationResourceResponse */

/**
 * Internal, private interface for JAXB reading and writing.
 */
@interface NEXUS_REST_APINS0GlobalConfigurationResourceResponse (JAXB) <JAXBReading, JAXBWriting, JAXBType, JAXBElement>

@end /*interface NEXUS_REST_APINS0GlobalConfigurationResourceResponse (JAXB)*/

/**
 * Internal, private implementation for JAXB reading and writing.
 */
@implementation NEXUS_REST_APINS0GlobalConfigurationResourceResponse (JAXB)

/**
 * Read an instance of NEXUS_REST_APINS0GlobalConfigurationResourceResponse from an XML reader.
 *
 * @param reader The reader.
 * @return An instance of NEXUS_REST_APINS0GlobalConfigurationResourceResponse defined by the XML reader.
 */
+ (id<JAXBType>) readXMLType: (xmlTextReaderPtr) reader
{
  NEXUS_REST_APINS0GlobalConfigurationResourceResponse *_nEXUS_REST_APINS0GlobalConfigurationResourceResponse = [[NEXUS_REST_APINS0GlobalConfigurationResourceResponse alloc] init];
  NS_DURING
  {
    [_nEXUS_REST_APINS0GlobalConfigurationResourceResponse initWithReader: reader];
  }
  NS_HANDLER
  {
    [_nEXUS_REST_APINS0GlobalConfigurationResourceResponse dealloc];
    _nEXUS_REST_APINS0GlobalConfigurationResourceResponse = nil;
    [localException raise];
  }
  NS_ENDHANDLER

  [_nEXUS_REST_APINS0GlobalConfigurationResourceResponse autorelease];
  return _nEXUS_REST_APINS0GlobalConfigurationResourceResponse;
}

/**
 * Initialize this instance of NEXUS_REST_APINS0GlobalConfigurationResourceResponse according to
 * the XML being read from the reader.
 *
 * @param reader The reader.
 */
- (id) initWithReader: (xmlTextReaderPtr) reader
{
  return [super initWithReader: reader];
}

/**
 * Write the XML for this instance of NEXUS_REST_APINS0GlobalConfigurationResourceResponse to the writer.
 * Note that since we're only writing the XML type,
 * No start/end element will be written.
 *
 * @param reader The reader.
 */
- (void) writeXMLType: (xmlTextWriterPtr) writer
{
  [super writeXMLType:writer];
}

/**
 * Reads a NEXUS_REST_APINS0GlobalConfigurationResourceResponse from an XML reader. The element to be read is
 * "global-settings".
 *
 * @param reader The XML reader.
 * @return The NEXUS_REST_APINS0GlobalConfigurationResourceResponse.
 */
+ (id<JAXBElement>) readXMLElement: (xmlTextReaderPtr) reader {
  int status;
  NEXUS_REST_APINS0GlobalConfigurationResourceResponse *_globalConfigurationResourceResponse = nil;

  if (xmlTextReaderNodeType(reader) != XML_READER_TYPE_ELEMENT) {
    status = xmlTextReaderAdvanceToNextStartOrEndElement(reader);
    if (status < 1) {
      [NSException raise: @"XMLReadError"
                   format: @"Error advancing the reader to start element global-settings."];
    }
  }

  if (xmlStrcmp(BAD_CAST "global-settings", xmlTextReaderConstLocalName(reader)) == 0
      && xmlTextReaderConstNamespaceUri(reader) == NULL) {
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read root element {}global-settings.");
#endif
    _globalConfigurationResourceResponse = (NEXUS_REST_APINS0GlobalConfigurationResourceResponse *)[NEXUS_REST_APINS0GlobalConfigurationResourceResponse readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"Successfully read root element {}global-settings.");
#endif
  }
  else {
    if (xmlTextReaderConstNamespaceUri(reader) == NULL) {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0GlobalConfigurationResourceResponse. Expected element global-settings. Current element: {}%s", xmlTextReaderConstLocalName(reader)];
    }
    else {
      [NSException raise: @"XMLReadError"
                   format: @"Unable to read NEXUS_REST_APINS0GlobalConfigurationResourceResponse. Expected element global-settings. Current element: {%s}%s\n", xmlTextReaderConstNamespaceUri(reader), xmlTextReaderConstLocalName(reader)];
    }
  }

  return _globalConfigurationResourceResponse;
}

/**
 * Writes this NEXUS_REST_APINS0GlobalConfigurationResourceResponse to XML under element name "global-settings".
 * The namespace declarations for the element will be written.
 *
 * @param writer The XML writer.
 * @param _globalConfigurationResourceResponse The GlobalConfigurationResourceResponse to write.
 * @return 1 if successful, 0 otherwise.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer
{
  [self writeXMLElement: writer writeNamespaces: YES];
}

/**
 * Writes this NEXUS_REST_APINS0GlobalConfigurationResourceResponse to an XML writer.
 *
 * @param writer The writer.
 * @param writeNs Whether to write the namespaces for this element to the xml writer.
 */
- (void) writeXMLElement: (xmlTextWriterPtr) writer writeNamespaces: (BOOL) writeNs
{
  int rc = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "global-settings", NULL);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing start element {}global-settings. XML writer status: %i\n", rc];
  }

#if DEBUG_ENUNCIATE > 1
  NSLog(@"writing type {}globalConfigurationResourceResponse for root element {}global-settings...");
#endif
  [self writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
  NSLog(@"successfully wrote type {}globalConfigurationResourceResponse for root element {}global-settings...");
#endif
  rc = xmlTextWriterEndElement(writer);
  if (rc < 0) {
    [NSException raise: @"XMLWriteError"
                 format: @"Error writing end element {}global-settings. XML writer status: %i\n", rc];
  }
}

//documentation inherited.
- (BOOL) readJAXBAttribute: (xmlTextReaderPtr) reader
{
  void *_child_accessor;

  if ([super readJAXBAttribute: reader]) {
    return YES;
  }

  return NO;
}

//documentation inherited.
- (BOOL) readJAXBValue: (xmlTextReaderPtr) reader
{
  return [super readJAXBValue: reader];
}

//documentation inherited.
- (BOOL) readJAXBChildElement: (xmlTextReaderPtr) reader
{
  id __child;
  void *_child_accessor;
  int status, depth;

  if ([super readJAXBChildElement: reader]) {
    return YES;
  }
  if (xmlTextReaderNodeType(reader) == XML_READER_TYPE_ELEMENT
    && xmlStrcmp(BAD_CAST "data", xmlTextReaderConstLocalName(reader)) == 0
    && xmlTextReaderConstNamespaceUri(reader) == NULL) {

#if DEBUG_ENUNCIATE > 1
    NSLog(@"Attempting to read choice {}data of type {}global-settings-item.");
#endif
    __child = [NEXUS_REST_APINS0GlobalConfigurationResource readXMLType: reader];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully read choice {}data of type {}global-settings-item.");
#endif

    [self setData: __child];
    return YES;
  } //end "if choice"


  return NO;
}

//documentation inherited.
- (int) readUnknownJAXBChildElement: (xmlTextReaderPtr) reader
{
  return [super readUnknownJAXBChildElement: reader];
}

//documentation inherited.
- (void) readUnknownJAXBAttribute: (xmlTextReaderPtr) reader
{
  [super readUnknownJAXBAttribute: reader];
}

//documentation inherited.
- (void) writeJAXBAttributes: (xmlTextWriterPtr) writer
{
  int status;

  [super writeJAXBAttributes: writer];

}

//documentation inherited.
- (void) writeJAXBValue: (xmlTextWriterPtr) writer
{
  [super writeJAXBValue: writer];
}

/**
 * Method for writing the child elements.
 *
 * @param writer The writer.
 */
- (void) writeJAXBChildElements: (xmlTextWriterPtr) writer
{
  int status;
  id __item;
  NSEnumerator *__enumerator;

  [super writeJAXBChildElements: writer];

  if ([self data]) {
    status = xmlTextWriterStartElementNS(writer, NULL, BAD_CAST "data", NULL);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing start child element {}data."];
    }

#if DEBUG_ENUNCIATE > 1
    NSLog(@"writing element {}data...");
#endif
    [[self data] writeXMLType: writer];
#if DEBUG_ENUNCIATE > 1
    NSLog(@"successfully wrote element {}data...");
#endif

    status = xmlTextWriterEndElement(writer);
    if (status < 0) {
      [NSException raise: @"XMLWriteError"
                   format: @"Error writing end child element {}data."];
    }
  }
}
@end /* implementation NEXUS_REST_APINS0GlobalConfigurationResourceResponse (JAXB) */

#endif /* DEF_NEXUS_REST_APINS0GlobalConfigurationResourceResponse_M */
